import inspect
import typing

from vkbottle_types.objects import NotesNote, NotesNoteComment
from vkbottle_types.responses.base_response import BaseResponse


class AddResponse(BaseResponse):
    response: int


class CreateCommentResponse(BaseResponse):
    response: int


class GetByIdResponse(BaseResponse):
    response: NotesNote


class GetCommentsResponse(BaseResponse):
    response: "GetCommentsResponseModel"


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class GetCommentsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["NotesNoteComment"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["NotesNote"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddResponse",
    "CreateCommentResponse",
    "GetByIdResponse",
    "GetCommentsResponse",
    "GetCommentsResponseModel",
    "GetResponse",
    "GetResponseModel",
    "NotesNote",
    "NotesNoteComment",
)



import inspect
import typing

from vkbottle_types.responses.base_response import BaseResponse


class GetServerUrlResponse(BaseResponse):
    response: "GetServerUrlResponseModel"


class GetServerUrlResponseModel(BaseResponse):
    endpoint: typing.Optional[str] = None
    key: typing.Optional[str] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "GetServerUrlResponse",
    "GetServerUrlResponseModel",
)



import inspect
import typing

from vkbottle_types.objects import (
    BaseBoolInt,
    BaseImage,
    BaseUploadServer,
    GroupsGroupFull,
    PhotosPhoto,
    PhotosPhotoAlbumFull,
    PhotosPhotoFullXtrRealOffset,
    PhotosPhotoTag,
    PhotosPhotoUpload,
    PhotosPhotoXtrRealOffset,
    PhotosPhotoXtrTagInfo,
    UsersUserFull,
    WallWallComment,
)
from vkbottle_types.responses.base_response import BaseResponse


class CopyResponse(BaseResponse):
    response: int


class CreateAlbumResponse(BaseResponse):
    response: PhotosPhotoAlbumFull


class CreateCommentResponse(BaseResponse):
    response: int


class DeleteCommentResponse(BaseResponse):
    response: BaseBoolInt


class GetAlbumsCountResponse(BaseResponse):
    response: int


class GetAlbumsResponse(BaseResponse):
    response: "GetAlbumsResponseModel"


class GetAllCommentsResponse(BaseResponse):
    response: "GetAllCommentsResponseModel"


class GetAllExtendedResponse(BaseResponse):
    response: "GetAllExtendedResponseModel"


class GetAllResponse(BaseResponse):
    response: "GetAllResponseModel"


class GetByIdResponse(BaseResponse):
    response: typing.List["PhotosPhoto"]


class GetCommentsExtendedResponse(BaseResponse):
    response: "GetCommentsExtendedResponseModel"


class GetCommentsResponse(BaseResponse):
    response: "GetCommentsResponseModel"


class GetMarketUploadServerResponse(BaseResponse):
    response: BaseUploadServer


class GetMessagesUploadServerResponse(BaseResponse):
    response: PhotosPhotoUpload


class GetNewTagsResponse(BaseResponse):
    response: "GetNewTagsResponseModel"


class GetTagsResponse(BaseResponse):
    response: typing.List["PhotosPhotoTag"]


class GetUploadServerResponse(BaseResponse):
    response: PhotosPhotoUpload


class GetUserPhotosResponse(BaseResponse):
    response: "GetUserPhotosResponseModel"


class GetWallUploadServerResponse(BaseResponse):
    response: PhotosPhotoUpload


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class MarketAlbumUploadResponse(BaseResponse):
    response: "MarketAlbumUploadResponseModel"


class MarketUploadResponse(BaseResponse):
    response: "MarketUploadResponseModel"


class MessageUploadResponse(BaseResponse):
    response: "MessageUploadResponseModel"


class OwnerCoverUploadResponse(BaseResponse):
    response: "OwnerCoverUploadResponseModel"


class OwnerUploadResponse(BaseResponse):
    response: "OwnerUploadResponseModel"


class PhotoUploadResponse(BaseResponse):
    response: "PhotoUploadResponseModel"


class PutTagResponse(BaseResponse):
    response: int


class RestoreCommentResponse(BaseResponse):
    response: BaseBoolInt


class SaveMarketAlbumPhotoResponse(BaseResponse):
    response: typing.List["PhotosPhoto"]


class SaveMarketPhotoResponse(BaseResponse):
    response: typing.List["PhotosPhoto"]


class SaveMessagesPhotoResponse(BaseResponse):
    response: typing.List["PhotosPhoto"]


class SaveOwnerCoverPhotoResponse(BaseResponse):
    response: "SaveOwnerCoverPhotoResponseModel"


class SaveOwnerPhotoResponse(BaseResponse):
    response: "SaveOwnerPhotoResponseModel"


class SaveWallPhotoResponse(BaseResponse):
    response: typing.List["PhotosPhoto"]


class SaveResponse(BaseResponse):
    response: typing.List["PhotosPhoto"]


class SearchResponse(BaseResponse):
    response: "SearchResponseModel"


class WallUploadResponse(BaseResponse):
    response: "WallUploadResponseModel"


class GetAlbumsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["PhotosPhotoAlbumFull"]] = None


class GetAllCommentsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallComment"]] = None


class GetAllExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["PhotosPhotoFullXtrRealOffset"]] = None
    more: typing.Optional["BaseBoolInt"] = None


class GetAllResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["PhotosPhotoXtrRealOffset"]] = None
    more: typing.Optional["BaseBoolInt"] = None


class GetCommentsExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    real_offset: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallComment"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetCommentsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    real_offset: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallComment"]] = None


class GetNewTagsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["PhotosPhotoXtrTagInfo"]] = None


class GetUserPhotosResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["PhotosPhoto"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["PhotosPhoto"]] = None


class MarketAlbumUploadResponseModel(BaseResponse):
    gid: typing.Optional[int] = None
    hash: typing.Optional[str] = None
    photo: typing.Optional[str] = None
    server: typing.Optional[int] = None


class MarketUploadResponseModel(BaseResponse):
    crop_data: typing.Optional[str] = None
    crop_hash: typing.Optional[str] = None
    group_id: typing.Optional[int] = None
    hash: typing.Optional[str] = None
    photo: typing.Optional[str] = None
    server: typing.Optional[int] = None


class MessageUploadResponseModel(BaseResponse):
    hash: typing.Optional[str] = None
    photo: typing.Optional[str] = None
    server: typing.Optional[int] = None


class OwnerCoverUploadResponseModel(BaseResponse):
    hash: typing.Optional[str] = None
    photo: typing.Optional[str] = None


class OwnerUploadResponseModel(BaseResponse):
    hash: typing.Optional[str] = None
    photo: typing.Optional[str] = None
    server: typing.Optional[int] = None


class PhotoUploadResponseModel(BaseResponse):
    aid: typing.Optional[int] = None
    hash: typing.Optional[str] = None
    photo: typing.Optional[str] = None
    photos_list: typing.Optional[str] = None
    server: typing.Optional[int] = None


class SaveOwnerCoverPhotoResponseModel(BaseResponse):
    images: typing.Optional[typing.List["BaseImage"]] = None


class SaveOwnerPhotoResponseModel(BaseResponse):
    photo_hash: typing.Optional[str] = None
    photo_src: typing.Optional[str] = None
    photo_src_big: typing.Optional[str] = None
    photo_src_small: typing.Optional[str] = None
    saved: typing.Optional[int] = None
    post_id: typing.Optional[int] = None


class SearchResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["PhotosPhoto"]] = None


class WallUploadResponseModel(BaseResponse):
    hash: typing.Optional[str] = None
    photo: typing.Optional[str] = None
    server: typing.Optional[int] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "BaseBoolInt",
    "BaseImage",
    "BaseUploadServer",
    "CopyResponse",
    "CreateAlbumResponse",
    "CreateCommentResponse",
    "DeleteCommentResponse",
    "GetAlbumsCountResponse",
    "GetAlbumsResponse",
    "GetAlbumsResponseModel",
    "GetAllCommentsResponse",
    "GetAllCommentsResponseModel",
    "GetAllExtendedResponse",
    "GetAllExtendedResponseModel",
    "GetAllResponse",
    "GetAllResponseModel",
    "GetByIdResponse",
    "GetCommentsExtendedResponse",
    "GetCommentsExtendedResponseModel",
    "GetCommentsResponse",
    "GetCommentsResponseModel",
    "GetMarketUploadServerResponse",
    "GetMessagesUploadServerResponse",
    "GetNewTagsResponse",
    "GetNewTagsResponseModel",
    "GetResponse",
    "GetResponseModel",
    "GetTagsResponse",
    "GetUploadServerResponse",
    "GetUserPhotosResponse",
    "GetUserPhotosResponseModel",
    "GetWallUploadServerResponse",
    "GroupsGroupFull",
    "MarketAlbumUploadResponse",
    "MarketAlbumUploadResponseModel",
    "MarketUploadResponse",
    "MarketUploadResponseModel",
    "MessageUploadResponse",
    "MessageUploadResponseModel",
    "OwnerCoverUploadResponse",
    "OwnerCoverUploadResponseModel",
    "OwnerUploadResponse",
    "OwnerUploadResponseModel",
    "PhotoUploadResponse",
    "PhotoUploadResponseModel",
    "PhotosPhoto",
    "PhotosPhotoAlbumFull",
    "PhotosPhotoFullXtrRealOffset",
    "PhotosPhotoTag",
    "PhotosPhotoUpload",
    "PhotosPhotoXtrRealOffset",
    "PhotosPhotoXtrTagInfo",
    "PutTagResponse",
    "RestoreCommentResponse",
    "SaveMarketAlbumPhotoResponse",
    "SaveMarketPhotoResponse",
    "SaveMessagesPhotoResponse",
    "SaveOwnerCoverPhotoResponse",
    "SaveOwnerCoverPhotoResponseModel",
    "SaveOwnerPhotoResponse",
    "SaveOwnerPhotoResponseModel",
    "SaveResponse",
    "SaveWallPhotoResponse",
    "SearchResponse",
    "SearchResponseModel",
    "UsersUserFull",
    "WallUploadResponse",
    "WallUploadResponseModel",
    "WallWallComment",
)



from typing import Union

from .bot_events import (
    AppPayload,
    AudioNew,
    BaseGroupEvent,
    BoardPostDelete,
    BoardPostEdit,
    BoardPostNew,
    BoardPostRestore,
    DonutMoneyWithdraw,
    DonutMoneyWithdrawError,
    DonutSubscriptionCancelled,
    DonutSubscriptionCreate,
    DonutSubscriptionExpired,
    DonutSubscriptionPriceChanged,
    DonutSubscriptionProlonged,
    GroupChangePhoto,
    GroupChangeSettings,
    GroupJoin,
    GroupLeave,
    GroupOfficersEdit,
    LikeAdd,
    LikeRemove,
    MarketCommentDelete,
    MarketCommentEdit,
    MarketCommentNew,
    MarketCommentRestore,
    MarketOrderEdit,
    MarketOrderNew,
    MessageAllow,
    MessageDeny,
    MessageEdit,
    MessageEvent,
    MessageNew,
    MessageReply,
    MessageTypingState,
    PhotoCommentDelete,
    PhotoCommentEdit,
    PhotoCommentNew,
    PhotoCommentRestore,
    PhotoNew,
    PollVoteNew,
    UserBlock,
    UserUnblock,
    VideoCommentDelete,
    VideoCommentEdit,
    VideoCommentNew,
    VideoCommentRestore,
    VideoNew,
    VkpayTransaction,
    WallPostNew,
    WallReplyDelete,
    WallReplyEdit,
    WallReplyNew,
    WallReplyRestore,
    WallRepost,
)


class GroupTypes:
    MessageNew = MessageNew
    MessageReply = MessageReply
    MessageEdit = MessageEdit
    MessageAllow = MessageAllow
    MessageDeny = MessageDeny
    MessageTypingState = MessageTypingState
    MessageEvent = MessageEvent
    PhotoNew = PhotoNew
    PhotoCommentNew = PhotoCommentNew
    PhotoCommentEdit = PhotoCommentEdit
    PhotoCommentRestore = PhotoCommentRestore
    PhotoCommentDelete = PhotoCommentDelete
    AudioNew = AudioNew
    VideoNew = VideoNew
    VideoCommentNew = VideoCommentNew
    VideoCommentEdit = VideoCommentEdit
    VideoCommentRestore = VideoCommentRestore
    VideoCommentDelete = VideoCommentDelete
    WallPostNew = WallPostNew
    WallRepost = WallRepost
    WallReplyNew = WallReplyNew
    WallReplyEdit = WallReplyEdit
    WallReplyRestore = WallReplyRestore
    WallReplyDelete = WallReplyDelete
    LikeAdd = LikeAdd
    LikeRemove = LikeRemove
    BoardPostNew = BoardPostNew
    BoardPostEdit = BoardPostEdit
    BoardPostRestore = BoardPostRestore
    BoardPostDelete = BoardPostDelete
    MarketCommentNew = MarketCommentNew
    MarketCommentEdit = MarketCommentEdit
    MarketCommentRestore = MarketCommentRestore
    MarketCommentDelete = MarketCommentDelete
    MarketOrderNew = MarketOrderNew
    MarketOrderEdit = MarketOrderEdit
    GroupLeave = GroupLeave
    GroupJoin = GroupJoin
    UserBlock = UserBlock
    UserUnblock = UserUnblock
    PollVoteNew = PollVoteNew
    GroupOfficersEdit = GroupOfficersEdit
    GroupChangeSettings = GroupChangeSettings
    GroupChangePhoto = GroupChangePhoto
    VkpayTransaction = VkpayTransaction
    AppPayload = AppPayload
    DonutSubscriptionCreate = DonutSubscriptionCreate
    DonutSubscriptionProlonged = DonutSubscriptionProlonged
    DonutSubscriptionExpired = DonutSubscriptionExpired
    DonutSubscriptionCancelled = DonutSubscriptionCancelled
    DonutSubscriptionPriceChanged = DonutSubscriptionPriceChanged
    DonutMoneyWithdraw = DonutMoneyWithdraw
    DonutMoneyWithdrawError = DonutMoneyWithdrawError

    UnifiedTypes = Union[
        BaseGroupEvent,
        MessageNew,
        MessageReply,
        MessageEdit,
        MessageAllow,
        MessageDeny,
        MessageTypingState,
        MessageEvent,
        PhotoNew,
        PhotoCommentNew,
        PhotoCommentEdit,
        PhotoCommentRestore,
        PhotoCommentDelete,
        AudioNew,
        VideoNew,
        VideoCommentNew,
        VideoCommentEdit,
        VideoCommentRestore,
        VideoCommentDelete,
        WallPostNew,
        WallRepost,
        WallReplyNew,
        WallReplyEdit,
        WallReplyRestore,
        WallReplyDelete,
        LikeAdd,
        LikeRemove,
        BoardPostNew,
        BoardPostEdit,
        BoardPostRestore,
        BoardPostDelete,
        MarketCommentNew,
        MarketCommentEdit,
        MarketCommentRestore,
        MarketCommentDelete,
        MarketOrderNew,
        MarketOrderEdit,
        GroupLeave,
        GroupJoin,
        UserBlock,
        UserUnblock,
        PollVoteNew,
        GroupOfficersEdit,
        GroupChangeSettings,
        GroupChangePhoto,
        VkpayTransaction,
        AppPayload,
        DonutSubscriptionCreate,
        DonutSubscriptionProlonged,
        DonutSubscriptionExpired,
        DonutSubscriptionCancelled,
        DonutSubscriptionPriceChanged,
        DonutMoneyWithdraw,
        DonutMoneyWithdrawError,
    ]



import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import OkResponse
from vkbottle_types.responses.streaming import (
    GetServerUrlResponse,
    GetServerUrlResponseModel,
)


class StreamingCategory(BaseCategory):
    async def get_server_url(self, **kwargs) -> GetServerUrlResponseModel:
        """Allows to receive data for the connection to Streaming API."""

        params = self.get_set_params(locals())
        response = await self.api.request("streaming.getServerUrl", params)
        model = GetServerUrlResponse
        return model(**response).response

    async def set_settings(
        self,
        monthly_tier: typing.Optional[
            Literal[
                "tier_1", "tier_2", "tier_3", "tier_4", "tier_5", "tier_6", "unlimited"
            ]
        ] = None,
        **kwargs
    ) -> int:
        """streaming.setSettings method

        :param monthly_tier:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("streaming.setSettings", params)
        model = OkResponse
        return model(**response).response


__all__ = ("StreamingCategory",)



import inspect
from typing import TYPE_CHECKING, Any, List, Optional, Union

from pydantic import BaseModel

from .enums import UserEventType
from .events_base import EventsBase
from .objects import BaseEventObject, user_event_objects

if TYPE_CHECKING:
    from vkbottle import ABCAPI, API


class BaseUserEvent(BaseModel):
    unprepared_ctx_api: Optional[Any] = None
    object: Optional["BaseEventObject"] = None

    def __init__(self, *args, **data: Any) -> None:
        data["object"] = args
        super().__init__(**data)

    @property
    def ctx_api(self) -> Optional[Union["ABCAPI", "API"]]:
        return getattr(self, "unprepared_ctx_api")


class RawUserEvent(BaseUserEvent):
    object: List[Any]


class ReplaceMessageFlags(BaseUserEvent):
    object: user_event_objects.ReplaceMessageFlagsObject


class InstallMessageFlags(BaseUserEvent):
    object: user_event_objects.InstallMessageFlagsObject


class ResetMessageFlags(BaseUserEvent):
    object: user_event_objects.ResetMessageFlagsObject


class MessageNew(BaseUserEvent):
    object: user_event_objects.MessageNewObject


class MessagesDelete(BaseUserEvent):
    object: user_event_objects.MessagesDeleteObject


class MessagesRestore(BaseUserEvent):
    object: user_event_objects.MessagesRestoreObject


class MessageEdit(BaseUserEvent):
    object: user_event_objects.MessageEditObject


class ChatVoiceMessageStates(BaseUserEvent):
    object: user_event_objects.ChatVoiceMessageStatesObject


class ChatEdit(BaseUserEvent):
    object: user_event_objects.ChatEditObject


class ChatInfoEdit(BaseUserEvent):
    object: user_event_objects.ChatInfoEditObject


class ChatTypingState(BaseUserEvent):
    object: user_event_objects.ConversationTypingStateObject


class DialogTypingState(BaseUserEvent):
    object: user_event_objects.DialogTypingStateObject


class UsersTypingState(BaseUserEvent):
    object: user_event_objects.UsersTypingStateObject


class ResetDialogFlags(BaseUserEvent):
    object: user_event_objects.ResetDialogFlagsObject


class ReplaceDialogFlags(BaseUserEvent):
    object: user_event_objects.ReplaceDialogFlagsObject


class InstallDialogFlags(BaseUserEvent):
    object: user_event_objects.InstallDialogFlagsObject


class FriendOnline(BaseUserEvent):
    object: user_event_objects.FriendOnlineObject


class FriendOffline(BaseUserEvent):
    object: user_event_objects.FriendOfflineObject


class Counter(BaseUserEvent):
    object: user_event_objects.CounterObject


class Call(BaseUserEvent):
    object: user_event_objects.CallObject


class NotificationsSettingsChanged(BaseUserEvent):
    object: user_event_objects.NotificationsSettingsChangedObject


class InRead(BaseUserEvent):
    object: user_event_objects.InReadObject


class OutRead(BaseUserEvent):
    object: user_event_objects.OutReadObject


DEFAULT_EVENTS_BASE_USER = EventsBase(UserEventType)
for item in locals().copy().values():
    if (
        not inspect.isclass(item)
        or not issubclass(item, BaseUserEvent)
        or item in (BaseUserEvent, RawUserEvent)
    ):
        continue
    item.update_forward_refs()
    event_type = UserEventType[
        "".join("_" + i if i.isupper() else i for i in item.__name__)
        .lstrip("_")
        .upper()
    ]
    DEFAULT_EVENTS_BASE_USER.register(event_type, item)
__all__ = (
    "DEFAULT_EVENTS_BASE_USER",
    "BaseUserEvent",
    "ReplaceMessageFlags",
    "InstallMessageFlags",
    "ResetMessageFlags",
    "MessageNew",
    "MessagesDelete",
    "MessagesRestore",
    "MessageEdit",
    "ChatVoiceMessageStates",
    "ChatEdit",
    "ChatInfoEdit",
    "ChatTypingState",
    "DialogTypingState",
    "UsersTypingState",
    "ResetDialogFlags",
    "ReplaceDialogFlags",
    "InstallDialogFlags",
    "FriendOnline",
    "FriendOffline",
    "Counter",
    "Call",
    "NotificationsSettingsChanged",
    "InRead",
    "OutRead",
)



import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import OkResponse
from vkbottle_types.responses.stats import (
    GetPostReachResponse,
    GetResponse,
    StatsPeriod,
    StatsWallpostStat,
)


class StatsCategory(BaseCategory):
    async def get(
        self,
        group_id: typing.Optional[int] = None,
        app_id: typing.Optional[int] = None,
        timestamp_from: typing.Optional[int] = None,
        timestamp_to: typing.Optional[int] = None,
        interval: typing.Optional[
            Literal["all", "day", "month", "week", "year"]
        ] = None,
        intervals_count: typing.Optional[int] = None,
        filters: typing.Optional[typing.List[str]] = None,
        stats_groups: typing.Optional[typing.List[str]] = None,
        extended: typing.Optional[bool] = None,
        **kwargs
    ) -> typing.List[StatsPeriod]:
        """Returns statistics of a community or an application.

        :param group_id: Community ID.
        :param app_id: Application ID.
        :param timestamp_from:
        :param timestamp_to:
        :param interval:
        :param intervals_count:
        :param filters:
        :param stats_groups:
        :param extended:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stats.get", params)
        model = GetResponse
        return model(**response).response

    async def get_post_reach(
        self, owner_id: str, post_ids: typing.List[int], **kwargs
    ) -> typing.List[StatsWallpostStat]:
        """Returns stats for a wall post.

        :param owner_id: post owner community id. Specify with "-" sign.
        :param post_ids: wall posts id
        """

        params = self.get_set_params(locals())
        response = await self.api.request("stats.getPostReach", params)
        model = GetPostReachResponse
        return model(**response).response

    async def track_visitor(self, **kwargs) -> int:
        """stats.trackVisitor method"""

        params = self.get_set_params(locals())
        response = await self.api.request("stats.trackVisitor", params)
        model = OkResponse
        return model(**response).response


__all__ = ("StatsCategory",)



import inspect
import typing

from vkbottle_types.objects import SearchHint
from vkbottle_types.responses.base_response import BaseResponse


class GetHintsResponse(BaseResponse):
    response: "GetHintsResponseModel"


class GetHintsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["SearchHint"]] = None
    suggested_queries: typing.Optional[typing.List[str]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "GetHintsResponse",
    "GetHintsResponseModel",
    "SearchHint",
)



import inspect
import typing

from vkbottle_types.objects import BaseSticker, StoreProduct, StoreStickersKeyword
from vkbottle_types.responses.base_response import BaseResponse


class GetFavoriteStickersResponse(BaseResponse):
    response: typing.List["BaseSticker"]


class GetProductsResponse(BaseResponse):
    response: typing.List["StoreProduct"]


class GetStickersKeywordsResponse(BaseResponse):
    response: "GetStickersKeywordsResponseModel"


class GetStickersKeywordsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    dictionary: typing.Optional[typing.List["StoreStickersKeyword"]] = None
    chunks_count: typing.Optional[int] = None
    chunks_hash: typing.Optional[str] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "BaseSticker",
    "GetFavoriteStickersResponse",
    "GetProductsResponse",
    "GetStickersKeywordsResponse",
    "GetStickersKeywordsResponseModel",
    "StoreProduct",
    "StoreStickersKeyword",
)



import inspect
import typing

from vkbottle_types.objects import (
    GroupsGroup,
    GroupsGroupFull,
    StoriesFeedItem,
    StoriesPromoBlock,
    StoriesStory,
    StoriesStoryStats,
    StoriesViewersItem,
    UsersUser,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class GetBannedExtendedResponse(BaseResponse):
    response: "GetBannedExtendedResponseModel"


class GetBannedResponse(BaseResponse):
    response: "GetBannedResponseModel"


class GetByIdExtendedResponse(BaseResponse):
    response: "GetByIdExtendedResponseModel"


class GetPhotoUploadServerResponse(BaseResponse):
    response: "GetPhotoUploadServerResponseModel"


class GetStatsResponse(BaseResponse):
    response: StoriesStoryStats


class GetVideoUploadServerResponse(BaseResponse):
    response: "GetVideoUploadServerResponseModel"


class GetViewersExtendedV5115Response(BaseResponse):
    response: "GetViewersExtendedV5115ResponseModel"


class GetViewersExtendedResponse(BaseResponse):
    response: "GetViewersExtendedResponseModel"


class GetV5113Response(BaseResponse):
    response: "GetV5113ResponseModel"


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class SaveResponse(BaseResponse):
    response: "SaveResponseModel"


class UploadResponse(BaseResponse):
    response: "UploadResponseModel"


class GetBannedExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetBannedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class GetByIdExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["StoriesStory"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetPhotoUploadServerResponseModel(BaseResponse):
    upload_url: typing.Optional[str] = None
    user_ids: typing.Optional[typing.List[int]] = None


class GetVideoUploadServerResponseModel(BaseResponse):
    upload_url: typing.Optional[str] = None
    user_ids: typing.Optional[typing.List[int]] = None


class GetViewersExtendedV5115ResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["StoriesViewersItem"]] = None
    hidden_reason: typing.Optional[str] = None
    next_from: typing.Optional[str] = None


class GetViewersExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


class GetV5113ResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["StoriesFeedItem"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None
    need_upload_screen: typing.Optional[bool] = None
    next_from: typing.Optional[str] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["list"]] = None
    promo_data: typing.Optional["StoriesPromoBlock"] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None
    need_upload_screen: typing.Optional[bool] = None


class SaveResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["StoriesStory"]] = None
    profiles: typing.Optional[typing.List["UsersUser"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None


class UploadResponseModel(BaseResponse):
    upload_result: typing.Optional[str] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "GetBannedExtendedResponse",
    "GetBannedExtendedResponseModel",
    "GetBannedResponse",
    "GetBannedResponseModel",
    "GetByIdExtendedResponse",
    "GetByIdExtendedResponseModel",
    "GetPhotoUploadServerResponse",
    "GetPhotoUploadServerResponseModel",
    "GetResponse",
    "GetResponseModel",
    "GetStatsResponse",
    "GetV5113Response",
    "GetV5113ResponseModel",
    "GetVideoUploadServerResponse",
    "GetVideoUploadServerResponseModel",
    "GetViewersExtendedResponse",
    "GetViewersExtendedResponseModel",
    "GetViewersExtendedV5115Response",
    "GetViewersExtendedV5115ResponseModel",
    "GroupsGroup",
    "GroupsGroupFull",
    "SaveResponse",
    "SaveResponseModel",
    "StoriesFeedItem",
    "StoriesPromoBlock",
    "StoriesStory",
    "StoriesStoryStats",
    "StoriesViewersItem",
    "UploadResponse",
    "UploadResponseModel",
    "UsersUser",
    "UsersUserFull",
)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.widgets import (
    GetCommentsResponse,
    GetCommentsResponseModel,
    GetPagesResponse,
    GetPagesResponseModel,
)


class WidgetsCategory(BaseCategory):
    async def get_comments(
        self,
        widget_api_id: typing.Optional[int] = None,
        url: typing.Optional[str] = None,
        page_id: typing.Optional[str] = None,
        order: typing.Optional[str] = None,
        fields: typing.Optional[typing.List[str]] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetCommentsResponseModel:
        """Gets a list of comments for the page added through the [vk.com/dev/Comments|Comments widget].

        :param widget_api_id:
        :param url:
        :param page_id:
        :param order:
        :param fields:
        :param offset:
        :param count:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("widgets.getComments", params)
        model = GetCommentsResponse
        return model(**response).response

    async def get_pages(
        self,
        widget_api_id: typing.Optional[int] = None,
        order: typing.Optional[str] = None,
        period: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetPagesResponseModel:
        """Gets a list of application/site pages where the [vk.com/dev/Comments|Comments widget] or [vk.com/dev/Like|Like widget] is installed.

        :param widget_api_id:
        :param order:
        :param period:
        :param offset:
        :param count:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("widgets.getPages", params)
        model = GetPagesResponse
        return model(**response).response


__all__ = ("WidgetsCategory",)



import inspect
import typing

from vkbottle_types.objects import (
    UtilsDomainResolved,
    UtilsLastShortenedLink,
    UtilsLinkChecked,
    UtilsLinkStats,
    UtilsLinkStatsExtended,
    UtilsShortLink,
)
from vkbottle_types.responses.base_response import BaseResponse


class CheckLinkResponse(BaseResponse):
    response: UtilsLinkChecked


class GetLastShortenedLinksResponse(BaseResponse):
    response: "GetLastShortenedLinksResponseModel"


class GetLinkStatsExtendedResponse(BaseResponse):
    response: UtilsLinkStatsExtended


class GetLinkStatsResponse(BaseResponse):
    response: UtilsLinkStats


class GetServerTimeResponse(BaseResponse):
    response: int


class GetShortLinkResponse(BaseResponse):
    response: UtilsShortLink


class ResolveScreenNameResponse(BaseResponse):
    response: UtilsDomainResolved


class GetLastShortenedLinksResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UtilsLastShortenedLink"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "CheckLinkResponse",
    "GetLastShortenedLinksResponse",
    "GetLastShortenedLinksResponseModel",
    "GetLinkStatsExtendedResponse",
    "GetLinkStatsResponse",
    "GetServerTimeResponse",
    "GetShortLinkResponse",
    "ResolveScreenNameResponse",
    "UtilsDomainResolved",
    "UtilsLastShortenedLink",
    "UtilsLinkChecked",
    "UtilsLinkStats",
    "UtilsLinkStatsExtended",
    "UtilsShortLink",
)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.pretty_cards import (
    CreateResponse,
    CreateResponseModel,
    DeleteResponse,
    DeleteResponseModel,
    EditResponse,
    EditResponseModel,
    GetByIdResponse,
    GetResponse,
    GetResponseModel,
    GetUploadURLResponse,
    PrettyCardsPrettyCardOrError,
)


class PrettyCardsCategory(BaseCategory):
    async def create(
        self,
        owner_id: int,
        photo: str,
        title: str,
        link: str,
        price: typing.Optional[str] = None,
        price_old: typing.Optional[str] = None,
        button: typing.Optional[str] = None,
        **kwargs
    ) -> CreateResponseModel:
        """prettyCards.create method

        :param owner_id:
        :param photo:
        :param title:
        :param link:
        :param price:
        :param price_old:
        :param button:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.create", params)
        model = CreateResponse
        return model(**response).response

    async def delete(
        self, owner_id: int, card_id: int, **kwargs
    ) -> DeleteResponseModel:
        """prettyCards.delete method

        :param owner_id:
        :param card_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.delete", params)
        model = DeleteResponse
        return model(**response).response

    async def edit(
        self,
        owner_id: int,
        card_id: int,
        photo: typing.Optional[str] = None,
        title: typing.Optional[str] = None,
        link: typing.Optional[str] = None,
        price: typing.Optional[str] = None,
        price_old: typing.Optional[str] = None,
        button: typing.Optional[str] = None,
        **kwargs
    ) -> EditResponseModel:
        """prettyCards.edit method

        :param owner_id:
        :param card_id:
        :param photo:
        :param title:
        :param link:
        :param price:
        :param price_old:
        :param button:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.edit", params)
        model = EditResponse
        return model(**response).response

    async def get(
        self,
        owner_id: int,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetResponseModel:
        """prettyCards.get method

        :param owner_id:
        :param offset:
        :param count:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.get", params)
        model = GetResponse
        return model(**response).response

    async def get_by_id(
        self, owner_id: int, card_ids: typing.List[int], **kwargs
    ) -> typing.List[PrettyCardsPrettyCardOrError]:
        """prettyCards.getById method

        :param owner_id:
        :param card_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.getById", params)
        model = GetByIdResponse
        return model(**response).response

    async def get_upload_url(self, **kwargs) -> str:
        """prettyCards.getUploadURL method"""

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.getUploadURL", params)
        model = GetUploadURLResponse
        return model(**response).response


__all__ = ("PrettyCardsCategory",)



# flake8: noqa: F405
import inspect
from pydantic import BaseModel
from enum import Enum
from typing import List, Optional
from vkbottle_types.codegen.objects import *  # noqa: F403,F401


class GroupsUserXtrRole(UsersUserFull, GroupsMemberRole):
    #  https://github.com/VKCOM/vk-api-schema/issues/224
    pass


class MessagesMessageAction(MessagesMessageAction):
    # https://github.com/VKCOM/vk-api-schema/issues/226
    style: Optional[str] = None


class MessagesMessageActionStatus(Enum):
    # https://github.com/VKCOM/vk-api-schema/issues/226
    CHAT_PHOTO_UPDATE = "chat_photo_update"
    CHAT_PHOTO_REMOVE = "chat_photo_remove"
    CHAT_CREATE = "chat_create"
    CHAT_TITLE_UPDATE = "chat_title_update"
    CHAT_INVITE_USER = "chat_invite_user"
    CHAT_KICK_USER = "chat_kick_user"
    CHAT_PIN_MESSAGE = "chat_pin_message"
    CHAT_UNPIN_MESSAGE = "chat_unpin_message"
    CHAT_INVITE_USER_BY_LINK = "chat_invite_user_by_link"
    CHAT_INVITE_USER_BY_MESSAGE_REQUEST = "chat_invite_user_by_message_request"
    CHAT_SCREENSHOT = "chat_screenshot"
    CONVERSATION_STYLE_UPDATE = "conversation_style_update"


class GroupCallInProgress(CallsCall):
    # https://github.com/VKCOM/vk-api-schema/issues/225
    receiver_id: Optional[int] = None
    time: Optional[int] = None
    join_link: Optional[str] = None
    state: Optional["CallsEndState"] = None


class MessagesMessageAttachment(MessagesMessageAttachment):
    # https://github.com/VKCOM/vk-api-schema/issues/225
    group_call_in_progress: Optional["GroupCallInProgress"] = None
    link: Optional["BaseLink"] = None
    wall: Optional["WallWallpostFull"] = None
    type: "MessagesMessageAttachmentType"


class BaseLinkAttachment(BaseLink):
    # https://github.com/VKCOM/vk-api-schema/issues/225
    photo: Optional["LinkPhoto"] = None


class LinkPhoto(PhotosPhoto):
    # https://github.com/VKCOM/vk-api-schema/issues/225
    has_tags: Optional[bool] = None
    date: Optional[int] = None


class MessagesMessage(MessagesMessage):
    # https://github.com/VKCOM/vk-api-schema/issues/225
    attachments: Optional[List["MessagesMessageAttachment"]] = None


class MessagesForeignMessage(MessagesForeignMessage):
    # https://github.com/VKCOM/vk-api-schema/issues/225
    attachments: Optional[List["MessagesMessageAttachment"]] = None


class MessagesMessageAttachmentType(Enum):
    PHOTO = "photo"
    AUDIO = "audio"
    VIDEO = "video"
    DOC = "doc"
    LINK = "link"
    MARKET = "market"
    MARKET_ALBUM = "market_album"
    GIFT = "gift"
    STICKER = "sticker"
    WALL = "wall"
    WALL_REPLY = "wall_reply"
    ARTICLE = "article"
    POLL = "poll"
    CALL = "call"
    GRAFFITI = "graffiti"
    AUDIO_MESSAGE = "audio_message"
    STORY = "story"
    GROUP_CALL_IN_PROGRESS = (
        "group_call_in_progress"  # https://github.com/VKCOM/vk-api-schema/issues/225
    )


class VideoVideoType(Enum):
    VIDEO = "video"
    MUSIC_VIDEO = "music_video"
    MOVIE = "movie"
    SHORT_VIDEO = "short_video"  # https://github.com/VKCOM/vk-api-schema/issues/212


class VideoVideo(VideoVideo):
    # https://github.com/VKCOM/vk-api-schema/issues/212
    type: Optional[VideoVideoType] = None


class MessagesSendUserIdsResponseItem(BaseModel):
    # https://github.com/VKCOM/vk-api-schema/issues/208
    conversation_message_id: Optional[int] = None
    error: Optional["BaseMessageError"] = None
    message_id: Optional[int]
    peer_id: int


GroupCallInProgress.update_forward_refs()
GroupsUserXtrRole.update_forward_refs()
MessagesForeignMessage.update_forward_refs()
MessagesHistoryMessageAttachment.update_forward_refs()
MessagesMessageAction.update_forward_refs()
MessagesMessageAttachment.update_forward_refs()
MessagesMessage.update_forward_refs()
MessagesSendUserIdsResponseItem.update_forward_refs()
NewsfeedItemWallpost.update_forward_refs()
VideoVideo.update_forward_refs()



from typing import List, Optional, Union

from vkbottle_types.codegen.methods.secure import SecureCategory
from vkbottle_types.responses.secure import (
    SecureSetCounterItem,
    SetCounterArrayResponse,
    SetCounterIntegerResponse,
)


class SecureCategory(SecureCategory):
    async def set_counter(
        self,
        counters: Optional[List[str]] = None,
        user_id: Optional[int] = None,
        counter: Optional[int] = None,
        increment: Optional[bool] = None,
        **kwargs
    ) -> Union[int, List["SecureSetCounterItem"]]:
        """Sets a counter which is shown to the user in bold in the left menu.

        :param counters:
        :param user_id:
        :param counter: counter value.
        :param increment:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.setCounter", params)
        if counters and counters.count(",") > 0:
            model = SetCounterArrayResponse
        else:
            model = SetCounterIntegerResponse
        return model(**response).response


__all__ = ("SecureCategory",)



import inspect
import typing

from vkbottle_types.objects import (
    AppsApp,
    AppsCatalogList,
    AppsLeaderboard,
    AppsScope,
    UsersUser,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class GetCatalogResponse(BaseResponse):
    response: AppsCatalogList


class GetFriendsListExtendedResponse(BaseResponse):
    response: "GetFriendsListExtendedResponseModel"


class GetFriendsListResponse(BaseResponse):
    response: "GetFriendsListResponseModel"


class GetLeaderboardExtendedResponse(BaseResponse):
    response: "GetLeaderboardExtendedResponseModel"


class GetLeaderboardResponse(BaseResponse):
    response: "GetLeaderboardResponseModel"


class GetMiniAppPoliciesResponse(BaseResponse):
    response: "GetMiniAppPoliciesResponseModel"


class GetScopesResponse(BaseResponse):
    response: "GetScopesResponseModel"


class GetScoreResponse(BaseResponse):
    response: int


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class ImageUploadResponse(BaseResponse):
    response: "ImageUploadResponseModel"


class SendRequestResponse(BaseResponse):
    response: int


class GetFriendsListExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


class GetFriendsListResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class GetLeaderboardExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AppsLeaderboard"]] = None
    profiles: typing.Optional[typing.List["UsersUser"]] = None


class GetLeaderboardResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AppsLeaderboard"]] = None


class GetMiniAppPoliciesResponseModel(BaseResponse):
    privacy_policy: typing.Optional[str] = None
    terms: typing.Optional[str] = None


class GetScopesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AppsScope"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AppsApp"]] = None


class ImageUploadResponseModel(BaseResponse):
    hash: typing.Optional[str] = None
    image: typing.Optional[str] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AppsApp",
    "AppsCatalogList",
    "AppsLeaderboard",
    "AppsScope",
    "GetCatalogResponse",
    "GetFriendsListExtendedResponse",
    "GetFriendsListExtendedResponseModel",
    "GetFriendsListResponse",
    "GetFriendsListResponseModel",
    "GetLeaderboardExtendedResponse",
    "GetLeaderboardExtendedResponseModel",
    "GetLeaderboardResponse",
    "GetLeaderboardResponseModel",
    "GetMiniAppPoliciesResponse",
    "GetMiniAppPoliciesResponseModel",
    "GetResponse",
    "GetResponseModel",
    "GetScopesResponse",
    "GetScopesResponseModel",
    "GetScoreResponse",
    "ImageUploadResponse",
    "ImageUploadResponseModel",
    "SendRequestResponse",
    "UsersUser",
    "UsersUserFull",
)



import inspect
import typing

from vkbottle_types.objects import (
    BaseCountry,
    BaseObject,
    DatabaseCity,
    DatabaseCityById,
    DatabaseFaculty,
    DatabaseRegion,
    DatabaseSchool,
    DatabaseStation,
    DatabaseUniversity,
)
from vkbottle_types.responses.base_response import BaseResponse


class GetChairsResponse(BaseResponse):
    response: "GetChairsResponseModel"


class GetCitiesByIdResponse(BaseResponse):
    response: typing.List["DatabaseCityById"]


class GetCitiesResponse(BaseResponse):
    response: "GetCitiesResponseModel"


class GetCountriesByIdResponse(BaseResponse):
    response: typing.List["BaseCountry"]


class GetCountriesResponse(BaseResponse):
    response: "GetCountriesResponseModel"


class GetFacultiesResponse(BaseResponse):
    response: "GetFacultiesResponseModel"


class GetMetroStationsByIdResponse(BaseResponse):
    response: typing.List["DatabaseStation"]


class GetMetroStationsResponse(BaseResponse):
    response: "GetMetroStationsResponseModel"


class GetRegionsResponse(BaseResponse):
    response: "GetRegionsResponseModel"


class GetSchoolClassesResponse(BaseResponse):
    response: typing.List[list]


class GetSchoolsResponse(BaseResponse):
    response: "GetSchoolsResponseModel"


class GetUniversitiesResponse(BaseResponse):
    response: "GetUniversitiesResponseModel"


class GetChairsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["BaseObject"]] = None


class GetCitiesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["DatabaseCity"]] = None


class GetCountriesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["BaseCountry"]] = None


class GetFacultiesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["DatabaseFaculty"]] = None


class GetMetroStationsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["DatabaseStation"]] = None


class GetRegionsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["DatabaseRegion"]] = None


class GetSchoolsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["DatabaseSchool"]] = None


class GetUniversitiesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["DatabaseUniversity"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "BaseCountry",
    "BaseObject",
    "DatabaseCity",
    "DatabaseCityById",
    "DatabaseFaculty",
    "DatabaseRegion",
    "DatabaseSchool",
    "DatabaseStation",
    "DatabaseUniversity",
    "GetChairsResponse",
    "GetChairsResponseModel",
    "GetCitiesByIdResponse",
    "GetCitiesResponse",
    "GetCitiesResponseModel",
    "GetCountriesByIdResponse",
    "GetCountriesResponse",
    "GetCountriesResponseModel",
    "GetFacultiesResponse",
    "GetFacultiesResponseModel",
    "GetMetroStationsByIdResponse",
    "GetMetroStationsResponse",
    "GetMetroStationsResponseModel",
    "GetRegionsResponse",
    "GetRegionsResponseModel",
    "GetSchoolClassesResponse",
    "GetSchoolsResponse",
    "GetSchoolsResponseModel",
    "GetUniversitiesResponse",
    "GetUniversitiesResponseModel",
)



import inspect
import typing

from vkbottle_types.objects import PodcastExternalData
from vkbottle_types.responses.base_response import BaseResponse


class SearchPodcastResponse(BaseResponse):
    response: "SearchPodcastResponseModel"


class SearchPodcastResponseModel(BaseResponse):
    podcasts: typing.Optional[typing.List["PodcastExternalData"]] = None
    results_total: typing.Optional[int] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "PodcastExternalData",
    "SearchPodcastResponse",
    "SearchPodcastResponseModel",
)



import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import BaseBoolInt, OkResponse
from vkbottle_types.responses.video import (
    AddAlbumResponse,
    AddAlbumResponseModel,
    ChangeVideoAlbumsResponse,
    CreateCommentResponse,
    GetAlbumByIdResponse,
    GetAlbumsByVideoExtendedResponse,
    GetAlbumsByVideoExtendedResponseModel,
    GetAlbumsByVideoResponse,
    GetAlbumsExtendedResponse,
    GetAlbumsExtendedResponseModel,
    GetAlbumsResponse,
    GetAlbumsResponseModel,
    GetCommentsExtendedResponse,
    GetCommentsExtendedResponseModel,
    GetCommentsResponse,
    GetCommentsResponseModel,
    GetResponse,
    GetResponseModel,
    RestoreCommentResponse,
    SaveResponse,
    SearchExtendedResponse,
    SearchExtendedResponseModel,
    SearchResponse,
    SearchResponseModel,
    VideoSaveResult,
    VideoVideoAlbumFull,
)


class VideoCategory(BaseCategory):
    async def add(
        self,
        video_id: int,
        owner_id: int,
        target_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Adds a video to a user or community page.

        :param video_id: Video ID.
        :param owner_id: ID of the user or community that owns the video. Use a negative value to designate a community ID.
        :param target_id: identifier of a user or community to add a video to. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.add", params)
        model = OkResponse
        return model(**response).response

    async def add_album(
        self,
        group_id: typing.Optional[int] = None,
        title: typing.Optional[str] = None,
        privacy: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> AddAlbumResponseModel:
        """Creates an empty album for videos.

        :param group_id: Community ID (if the album will be created in a community).
        :param title: Album title.
        :param privacy: new access permissions for the album. Possible values: , *'0' - all users,, *'1' - friends only,, *'2' - friends and friends of friends,, *'3' - "only me".
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.addAlbum", params)
        model = AddAlbumResponse
        return model(**response).response

    async def add_to_album(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = None,
        album_ids: typing.Optional[typing.List[int]] = None,
        **kwargs
    ) -> int:
        """video.addToAlbum method

        :param owner_id:
        :param video_id:
        :param target_id:
        :param album_id:
        :param album_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.addToAlbum", params)
        model = self.get_model(
            ((("multi",), ChangeVideoAlbumsResponse),),
            default=OkResponse,
            params=params,
        )
        return model(**response).response

    async def create_comment(
        self,
        video_id: int,
        owner_id: typing.Optional[int] = None,
        message: typing.Optional[str] = None,
        attachments: typing.Optional[typing.List[str]] = None,
        from_group: typing.Optional[bool] = None,
        reply_to_comment: typing.Optional[int] = None,
        sticker_id: typing.Optional[int] = None,
        guid: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """Adds a new comment on a video.

        :param video_id: Video ID.
        :param owner_id: ID of the user or community that owns the video.
        :param message: New comment text.
        :param attachments: List of objects attached to the comment, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, '<owner_id>' — ID of the media attachment owner. '<media_id>' — Media attachment ID. Example: "photo100172_166443618,photo66748_265827614"
        :param from_group: '1' — to post the comment from a community name (only if 'owner_id'<0)
        :param reply_to_comment:
        :param sticker_id:
        :param guid:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.createComment", params)
        model = CreateCommentResponse
        return model(**response).response

    async def delete(
        self,
        video_id: int,
        owner_id: typing.Optional[int] = None,
        target_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Deletes a video from a user or community page.

        :param video_id: Video ID.
        :param owner_id: ID of the user or community that owns the video.
        :param target_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.delete", params)
        model = OkResponse
        return model(**response).response

    async def delete_album(
        self, album_id: int, group_id: typing.Optional[int] = None, **kwargs
    ) -> int:
        """Deletes a video album.

        :param album_id: Album ID.
        :param group_id: Community ID (if the album is owned by a community).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.deleteAlbum", params)
        model = OkResponse
        return model(**response).response

    async def delete_comment(
        self, comment_id: int, owner_id: typing.Optional[int] = None, **kwargs
    ) -> int:
        """Deletes a comment on a video.

        :param comment_id: ID of the comment to be deleted.
        :param owner_id: ID of the user or community that owns the video.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.deleteComment", params)
        model = OkResponse
        return model(**response).response

    async def edit(
        self,
        video_id: int,
        owner_id: typing.Optional[int] = None,
        name: typing.Optional[str] = None,
        desc: typing.Optional[str] = None,
        privacy_view: typing.Optional[typing.List[str]] = None,
        privacy_comment: typing.Optional[typing.List[str]] = None,
        no_comments: typing.Optional[bool] = None,
        repeat: typing.Optional[bool] = None,
        **kwargs
    ) -> int:
        """Edits information about a video on a user or community page.

        :param video_id: Video ID.
        :param owner_id: ID of the user or community that owns the video.
        :param name: New video title.
        :param desc: New video description.
        :param privacy_view: Privacy settings in a [vk.com/dev/privacy_setting|special format]. Privacy setting is available for videos uploaded to own profile by user.
        :param privacy_comment: Privacy settings for comments in a [vk.com/dev/privacy_setting|special format].
        :param no_comments: Disable comments for the group video.
        :param repeat: '1' — to repeat the playback of the video, '0' — to play the video once,
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.edit", params)
        model = OkResponse
        return model(**response).response

    async def edit_album(
        self,
        album_id: int,
        title: str,
        group_id: typing.Optional[int] = None,
        privacy: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> int:
        """Edits the title of a video album.

        :param album_id: Album ID.
        :param title: New album title.
        :param group_id: Community ID (if the album edited is owned by a community).
        :param privacy: new access permissions for the album. Possible values: , *'0' - all users,, *'1' - friends only,, *'2' - friends and friends of friends,, *'3' - "only me".
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.editAlbum", params)
        model = OkResponse
        return model(**response).response

    async def edit_comment(
        self,
        comment_id: int,
        owner_id: typing.Optional[int] = None,
        message: typing.Optional[str] = None,
        attachments: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> int:
        """Edits the text of a comment on a video.

        :param comment_id: Comment ID.
        :param owner_id: ID of the user or community that owns the video.
        :param message: New comment text.
        :param attachments: List of objects attached to the comment, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, '<owner_id>' — ID of the media attachment owner. '<media_id>' — Media attachment ID. Example: "photo100172_166443618,photo66748_265827614"
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.editComment", params)
        model = OkResponse
        return model(**response).response

    async def get(
        self,
        owner_id: typing.Optional[int] = None,
        videos: typing.Optional[typing.List[str]] = None,
        album_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        extended: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> GetResponseModel:
        """Returns detailed information about videos.

        :param owner_id: ID of the user or community that owns the video(s).
        :param videos: Video IDs, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", Use a negative value to designate a community ID. Example: "-4363_136089719,13245770_137352259"
        :param album_id: ID of the album containing the video(s).
        :param count: Number of videos to return.
        :param offset: Offset needed to return a specific subset of videos.
        :param extended: '1' — to return an extended response with additional fields
        :param fields:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.get", params)
        model = GetResponse
        return model(**response).response

    async def get_album_by_id(
        self, album_id: int, owner_id: typing.Optional[int] = None, **kwargs
    ) -> VideoVideoAlbumFull:
        """Returns video album info

        :param album_id: Album ID.
        :param owner_id: identifier of a user or community to add a video to. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.getAlbumById", params)
        model = GetAlbumByIdResponse
        return model(**response).response

    @typing.overload
    async def get_albums(
        self,
        owner_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: typing.Optional[Literal[False]] = ...,
        need_system: typing.Optional[bool] = None,
        **kwargs
    ) -> GetAlbumsResponseModel:
        ...

    @typing.overload
    async def get_albums(
        self,
        owner_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: Literal[True] = ...,
        need_system: typing.Optional[bool] = None,
        **kwargs
    ) -> GetAlbumsExtendedResponseModel:
        ...

    async def get_albums(
        self,
        owner_id=None,
        offset=None,
        count=None,
        extended=None,
        need_system=None,
        **kwargs
    ) -> typing.Union[GetAlbumsResponseModel, GetAlbumsExtendedResponseModel]:
        """Returns a list of video albums owned by a user or community.

        :param owner_id: ID of the user or community that owns the video album(s).
        :param offset: Offset needed to return a specific subset of video albums.
        :param count: Number of video albums to return.
        :param extended: '1' — to return additional information about album privacy settings for the current user
        :param need_system:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.getAlbums", params)
        model = self.get_model(
            ((("extended",), GetAlbumsExtendedResponse),),
            default=GetAlbumsResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def get_albums_by_video(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        extended: typing.Optional[Literal[False]] = ...,
        **kwargs
    ) -> typing.List[int]:
        ...

    @typing.overload
    async def get_albums_by_video(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        extended: Literal[True] = ...,
        **kwargs
    ) -> GetAlbumsByVideoExtendedResponseModel:
        ...

    async def get_albums_by_video(
        self, owner_id=None, video_id=None, target_id=None, extended=None, **kwargs
    ) -> typing.Union[typing.List[int], GetAlbumsByVideoExtendedResponseModel]:
        """video.getAlbumsByVideo method

        :param owner_id:
        :param video_id:
        :param target_id:
        :param extended:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.getAlbumsByVideo", params)
        model = self.get_model(
            ((("extended",), GetAlbumsByVideoExtendedResponse),),
            default=GetAlbumsByVideoResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def get_comments(
        self,
        video_id: int,
        owner_id: typing.Optional[int] = None,
        need_likes: typing.Optional[bool] = None,
        start_comment_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        sort: typing.Optional[Literal["asc", "desc"]] = None,
        extended: typing.Optional[Literal[False]] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> GetCommentsResponseModel:
        ...

    @typing.overload
    async def get_comments(
        self,
        video_id: int,
        owner_id: typing.Optional[int] = None,
        need_likes: typing.Optional[bool] = None,
        start_comment_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        sort: typing.Optional[Literal["asc", "desc"]] = None,
        extended: Literal[True] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> GetCommentsExtendedResponseModel:
        ...

    async def get_comments(
        self,
        video_id=None,
        owner_id=None,
        need_likes=None,
        start_comment_id=None,
        offset=None,
        count=None,
        sort=None,
        extended=None,
        fields=None,
        **kwargs
    ) -> typing.Union[GetCommentsResponseModel, GetCommentsExtendedResponseModel]:
        """Returns a list of comments on a video.

        :param video_id: Video ID.
        :param owner_id: ID of the user or community that owns the video.
        :param need_likes: '1' — to return an additional 'likes' field
        :param start_comment_id:
        :param offset: Offset needed to return a specific subset of comments.
        :param count: Number of comments to return.
        :param sort: Sort order: 'asc' — oldest comment first, 'desc' — newest comment first
        :param extended:
        :param fields:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.getComments", params)
        model = self.get_model(
            ((("extended",), GetCommentsExtendedResponse),),
            default=GetCommentsResponse,
            params=params,
        )
        return model(**response).response

    async def remove_from_album(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = None,
        album_ids: typing.Optional[typing.List[int]] = None,
        **kwargs
    ) -> int:
        """video.removeFromAlbum method

        :param owner_id:
        :param video_id:
        :param target_id:
        :param album_id:
        :param album_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.removeFromAlbum", params)
        model = self.get_model(
            ((("multi",), ChangeVideoAlbumsResponse),),
            default=OkResponse,
            params=params,
        )
        return model(**response).response

    async def reorder_albums(
        self,
        album_id: int,
        owner_id: typing.Optional[int] = None,
        before: typing.Optional[int] = None,
        after: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Reorders the album in the list of user video albums.

        :param album_id: Album ID.
        :param owner_id: ID of the user or community that owns the albums..
        :param before: ID of the album before which the album in question shall be placed.
        :param after: ID of the album after which the album in question shall be placed.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.reorderAlbums", params)
        model = OkResponse
        return model(**response).response

    async def reorder_videos(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = None,
        before_owner_id: typing.Optional[int] = None,
        before_video_id: typing.Optional[int] = None,
        after_owner_id: typing.Optional[int] = None,
        after_video_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Reorders the video in the video album.

        :param owner_id: ID of the user or community that owns the video.
        :param video_id: ID of the video.
        :param target_id: ID of the user or community that owns the album with videos.
        :param album_id: ID of the video album.
        :param before_owner_id: ID of the user or community that owns the video before which the video in question shall be placed.
        :param before_video_id: ID of the video before which the video in question shall be placed.
        :param after_owner_id: ID of the user or community that owns the video after which the photo in question shall be placed.
        :param after_video_id: ID of the video after which the photo in question shall be placed.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.reorderVideos", params)
        model = OkResponse
        return model(**response).response

    async def report(
        self,
        owner_id: int,
        video_id: int,
        reason: typing.Optional[Literal[0, 1, 2, 3, 4, 5, 6]] = None,
        comment: typing.Optional[str] = None,
        search_query: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """Reports (submits a complaint about) a video.

        :param owner_id: ID of the user or community that owns the video.
        :param video_id: Video ID.
        :param reason: Reason for the complaint: '0' - spam, '1' - child pornography, '2' - extremism, '3' - violence, '4' - drug propaganda, '5' - adult material, '6' - insult, abuse
        :param comment: Comment describing the complaint.
        :param search_query: (If the video was found in search results.) Search query string.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.report", params)
        model = OkResponse
        return model(**response).response

    async def report_comment(
        self,
        owner_id: int,
        comment_id: int,
        reason: typing.Optional[Literal[0, 1, 2, 3, 4, 5, 6]] = None,
        **kwargs
    ) -> int:
        """Reports (submits a complaint about) a comment on a video.

        :param owner_id: ID of the user or community that owns the video.
        :param comment_id: ID of the comment being reported.
        :param reason: Reason for the complaint: , 0 - spam , 1 - child pornography , 2 - extremism , 3 - violence , 4 - drug propaganda , 5 - adult material , 6 - insult, abuse
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.reportComment", params)
        model = OkResponse
        return model(**response).response

    async def restore(
        self, video_id: int, owner_id: typing.Optional[int] = None, **kwargs
    ) -> int:
        """Restores a previously deleted video.

        :param video_id: Video ID.
        :param owner_id: ID of the user or community that owns the video.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.restore", params)
        model = OkResponse
        return model(**response).response

    async def restore_comment(
        self, comment_id: int, owner_id: typing.Optional[int] = None, **kwargs
    ) -> BaseBoolInt:
        """Restores a previously deleted comment on a video.

        :param comment_id: ID of the deleted comment.
        :param owner_id: ID of the user or community that owns the video.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.restoreComment", params)
        model = RestoreCommentResponse
        return model(**response).response

    async def save(
        self,
        name: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        is_private: typing.Optional[bool] = None,
        wallpost: typing.Optional[bool] = None,
        link: typing.Optional[str] = None,
        group_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = None,
        privacy_view: typing.Optional[typing.List[str]] = None,
        privacy_comment: typing.Optional[typing.List[str]] = None,
        no_comments: typing.Optional[bool] = None,
        repeat: typing.Optional[bool] = None,
        compression: typing.Optional[bool] = None,
        **kwargs
    ) -> VideoSaveResult:
        """Returns a server address (required for upload) and video data.

        :param name: Name of the video.
        :param description: Description of the video.
        :param is_private: '1' — to designate the video as private (send it via a private message), the video will not appear on the user's video list and will not be available by ID for other users, '0' — not to designate the video as private
        :param wallpost: '1' — to post the saved video on a user's wall, '0' — not to post the saved video on a user's wall
        :param link: URL for embedding the video from an external website.
        :param group_id: ID of the community in which the video will be saved. By default, the current user's page.
        :param album_id: ID of the album to which the saved video will be added.
        :param privacy_view:
        :param privacy_comment:
        :param no_comments:
        :param repeat: '1' — to repeat the playback of the video, '0' — to play the video once,
        :param compression:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.save", params)
        model = SaveResponse
        return model(**response).response

    @typing.overload
    async def search(
        self,
        q: typing.Optional[str] = None,
        sort: typing.Optional[Literal[1, 2, 0]] = None,
        hd: typing.Optional[int] = None,
        adult: typing.Optional[bool] = None,
        live: typing.Optional[bool] = None,
        filters: typing.Optional[typing.List[str]] = None,
        search_own: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        longer: typing.Optional[int] = None,
        shorter: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: typing.Optional[Literal[False]] = ...,
        **kwargs
    ) -> SearchResponseModel:
        ...

    @typing.overload
    async def search(
        self,
        q: typing.Optional[str] = None,
        sort: typing.Optional[Literal[1, 2, 0]] = None,
        hd: typing.Optional[int] = None,
        adult: typing.Optional[bool] = None,
        live: typing.Optional[bool] = None,
        filters: typing.Optional[typing.List[str]] = None,
        search_own: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        longer: typing.Optional[int] = None,
        shorter: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: Literal[True] = ...,
        **kwargs
    ) -> SearchExtendedResponseModel:
        ...

    async def search(
        self,
        q=None,
        sort=None,
        hd=None,
        adult=None,
        live=None,
        filters=None,
        search_own=None,
        offset=None,
        longer=None,
        shorter=None,
        count=None,
        extended=None,
        **kwargs
    ) -> typing.Union[SearchResponseModel, SearchExtendedResponseModel]:
        """Returns a list of videos under the set search criterion.

        :param q: Search query string (e.g., 'The Beatles').
        :param sort: Sort order: '1' — by duration, '2' — by relevance, '0' — by date added
        :param hd: If not null, only searches for high-definition videos.
        :param adult: '1' — to disable the Safe Search filter, '0' — to enable the Safe Search filter
        :param live:
        :param filters: Filters to apply: 'youtube' — return YouTube videos only, 'vimeo' — return Vimeo videos only, 'short' — return short videos only, 'long' — return long videos only
        :param search_own:
        :param offset: Offset needed to return a specific subset of videos.
        :param longer:
        :param shorter:
        :param count: Number of videos to return.
        :param extended:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.search", params)
        model = self.get_model(
            ((("extended",), SearchExtendedResponse),),
            default=SearchResponse,
            params=params,
        )
        return model(**response).response


__all__ = ("VideoCategory",)



import inspect
import typing

from vkbottle_types.objects import (
    AdsAccount,
    AdsAd,
    AdsAdLayout,
    AdsCampaign,
    AdsCategory,
    AdsClient,
    AdsCreateAdStatus,
    AdsCreateCampaignStatus,
    AdsDemoStats,
    AdsFloodStats,
    AdsLinkStatus,
    AdsLookalikeRequest,
    AdsMusician,
    AdsPromotedPostReach,
    AdsRejectReason,
    AdsStats,
    AdsTargetGroup,
    AdsTargSettings,
    AdsTargStats,
    AdsTargSuggestions,
    AdsTargSuggestionsCities,
    AdsTargSuggestionsRegions,
    AdsTargSuggestionsSchools,
    AdsUpdateOfficeUsersResult,
    AdsUsers,
)
from vkbottle_types.responses.base_response import BaseResponse


class AddOfficeUsersResponse(BaseResponse):
    response: bool


class CheckLinkResponse(BaseResponse):
    response: AdsLinkStatus


class CreateAdsResponse(BaseResponse):
    response: typing.List["AdsCreateAdStatus"]


class CreateCampaignsResponse(BaseResponse):
    response: typing.List["AdsCreateCampaignStatus"]


class CreateClientsResponse(BaseResponse):
    response: typing.List[int]


class CreateTargetGroupResponse(BaseResponse):
    response: "CreateTargetGroupResponseModel"


class DeleteAdsResponse(BaseResponse):
    response: typing.List[int]


class DeleteCampaignsResponse(BaseResponse):
    response: typing.List[int]


class DeleteClientsResponse(BaseResponse):
    response: typing.List[int]


class GetAccountsResponse(BaseResponse):
    response: typing.List["AdsAccount"]


class GetAdsLayoutResponse(BaseResponse):
    response: typing.List["AdsAdLayout"]


class GetAdsTargetingResponse(BaseResponse):
    response: typing.List["AdsTargSettings"]


class GetAdsResponse(BaseResponse):
    response: typing.List["AdsAd"]


class GetBudgetResponse(BaseResponse):
    response: int


class GetCampaignsResponse(BaseResponse):
    response: typing.List["AdsCampaign"]


class GetCategoriesResponse(BaseResponse):
    response: "GetCategoriesResponseModel"


class GetClientsResponse(BaseResponse):
    response: typing.List["AdsClient"]


class GetDemographicsResponse(BaseResponse):
    response: typing.List["AdsDemoStats"]


class GetFloodStatsResponse(BaseResponse):
    response: AdsFloodStats


class GetLookalikeRequestsResponse(BaseResponse):
    response: "GetLookalikeRequestsResponseModel"


class GetMusiciansResponse(BaseResponse):
    response: "GetMusiciansResponseModel"


class GetOfficeUsersResponse(BaseResponse):
    response: typing.List["AdsUsers"]


class GetPostsReachResponse(BaseResponse):
    response: typing.List["AdsPromotedPostReach"]


class GetRejectionReasonResponse(BaseResponse):
    response: AdsRejectReason


class GetStatisticsResponse(BaseResponse):
    response: typing.List["AdsStats"]


class GetSuggestionsCitiesResponse(BaseResponse):
    response: typing.List["AdsTargSuggestionsCities"]


class GetSuggestionsRegionsResponse(BaseResponse):
    response: typing.List["AdsTargSuggestionsRegions"]


class GetSuggestionsResponse(BaseResponse):
    response: typing.List["AdsTargSuggestions"]


class GetSuggestionsSchoolsResponse(BaseResponse):
    response: typing.List["AdsTargSuggestionsSchools"]


class GetTargetGroupsResponse(BaseResponse):
    response: typing.List["AdsTargetGroup"]


class GetTargetingStatsResponse(BaseResponse):
    response: AdsTargStats


class GetUploadURLResponse(BaseResponse):
    response: str


class GetVideoUploadURLResponse(BaseResponse):
    response: str


class ImportTargetContactsResponse(BaseResponse):
    response: int


class RemoveOfficeUsersResponse(BaseResponse):
    response: bool


class UpdateAdsResponse(BaseResponse):
    response: typing.List[int]


class UpdateCampaignsResponse(BaseResponse):
    response: int


class UpdateClientsResponse(BaseResponse):
    response: int


class UpdateOfficeUsersResponse(BaseResponse):
    response: typing.List["AdsUpdateOfficeUsersResult"]


class CreateTargetGroupResponseModel(BaseResponse):
    id: typing.Optional[int] = None
    pixel: typing.Optional[str] = None


class GetCategoriesResponseModel(BaseResponse):
    v1: typing.Optional[typing.List["AdsCategory"]] = None
    v2: typing.Optional[typing.List["AdsCategory"]] = None


class GetLookalikeRequestsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AdsLookalikeRequest"]] = None


class GetMusiciansResponseModel(BaseResponse):
    items: typing.Optional[typing.List["AdsMusician"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddOfficeUsersResponse",
    "AdsAccount",
    "AdsAd",
    "AdsAdLayout",
    "AdsCampaign",
    "AdsCategory",
    "AdsClient",
    "AdsCreateAdStatus",
    "AdsCreateCampaignStatus",
    "AdsDemoStats",
    "AdsFloodStats",
    "AdsLinkStatus",
    "AdsLookalikeRequest",
    "AdsMusician",
    "AdsPromotedPostReach",
    "AdsRejectReason",
    "AdsStats",
    "AdsTargSettings",
    "AdsTargStats",
    "AdsTargSuggestions",
    "AdsTargSuggestionsCities",
    "AdsTargSuggestionsRegions",
    "AdsTargSuggestionsSchools",
    "AdsTargetGroup",
    "AdsUpdateOfficeUsersResult",
    "AdsUsers",
    "CheckLinkResponse",
    "CreateAdsResponse",
    "CreateCampaignsResponse",
    "CreateClientsResponse",
    "CreateTargetGroupResponse",
    "CreateTargetGroupResponseModel",
    "DeleteAdsResponse",
    "DeleteCampaignsResponse",
    "DeleteClientsResponse",
    "GetAccountsResponse",
    "GetAdsLayoutResponse",
    "GetAdsResponse",
    "GetAdsTargetingResponse",
    "GetBudgetResponse",
    "GetCampaignsResponse",
    "GetCategoriesResponse",
    "GetCategoriesResponseModel",
    "GetClientsResponse",
    "GetDemographicsResponse",
    "GetFloodStatsResponse",
    "GetLookalikeRequestsResponse",
    "GetLookalikeRequestsResponseModel",
    "GetMusiciansResponse",
    "GetMusiciansResponseModel",
    "GetOfficeUsersResponse",
    "GetPostsReachResponse",
    "GetRejectionReasonResponse",
    "GetStatisticsResponse",
    "GetSuggestionsCitiesResponse",
    "GetSuggestionsRegionsResponse",
    "GetSuggestionsResponse",
    "GetSuggestionsSchoolsResponse",
    "GetTargetGroupsResponse",
    "GetTargetingStatsResponse",
    "GetUploadURLResponse",
    "GetVideoUploadURLResponse",
    "ImportTargetContactsResponse",
    "RemoveOfficeUsersResponse",
    "UpdateAdsResponse",
    "UpdateCampaignsResponse",
    "UpdateClientsResponse",
    "UpdateOfficeUsersResponse",
)



import inspect
import typing

from vkbottle_types.responses.base_response import BaseResponse


class RestoreResponse(BaseResponse):
    response: "RestoreResponseModel"


class RestoreResponseModel(BaseResponse):
    success: typing.Optional[int] = None
    sid: typing.Optional[str] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "RestoreResponse",
    "RestoreResponseModel",
)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import BaseBoolInt, BoolResponse
from vkbottle_types.responses.donut import (
    DonutDonatorSubscriptionInfo,
    GetSubscriptionResponse,
    GetSubscriptionsResponse,
    GetSubscriptionsResponseModel,
)
from vkbottle_types.responses.groups import (
    GetMembersFieldsResponse,
    GetMembersFieldsResponseModel,
)


class DonutCategory(BaseCategory):
    async def get_friends(
        self,
        owner_id: int,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> GetMembersFieldsResponseModel:
        """donut.getFriends method

        :param owner_id:
        :param offset:
        :param count:
        :param fields:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("donut.getFriends", params)
        model = GetMembersFieldsResponse
        return model(**response).response

    async def get_subscription(
        self, owner_id: int, **kwargs
    ) -> DonutDonatorSubscriptionInfo:
        """donut.getSubscription method

        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("donut.getSubscription", params)
        model = GetSubscriptionResponse
        return model(**response).response

    async def get_subscriptions(
        self,
        fields: typing.Optional[typing.List[str]] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetSubscriptionsResponseModel:
        """Returns a list of user's VK Donut subscriptions.

        :param fields:
        :param offset:
        :param count:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("donut.getSubscriptions", params)
        model = GetSubscriptionsResponse
        return model(**response).response

    async def is_don(self, owner_id: int, **kwargs) -> BaseBoolInt:
        """donut.isDon method

        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("donut.isDon", params)
        model = BoolResponse
        return model(**response).response


__all__ = ("DonutCategory",)



import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import BaseBoolInt, BoolResponse, OkResponse
from vkbottle_types.responses.fave import (
    AddTagResponse,
    FaveTag,
    GetExtendedResponse,
    GetExtendedResponseModel,
    GetPagesResponse,
    GetPagesResponseModel,
    GetResponse,
    GetResponseModel,
    GetTagsResponse,
    GetTagsResponseModel,
)


class FaveCategory(BaseCategory):
    async def add_article(self, url: str, **kwargs) -> int:
        """fave.addArticle method

        :param url:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addArticle", params)
        model = OkResponse
        return model(**response).response

    async def add_link(self, link: str, **kwargs) -> int:
        """Adds a link to user faves.

        :param link: Link URL.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addLink", params)
        model = OkResponse
        return model(**response).response

    async def add_page(
        self,
        user_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """fave.addPage method

        :param user_id:
        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addPage", params)
        model = OkResponse
        return model(**response).response

    async def add_post(
        self, owner_id: int, id: int, access_key: typing.Optional[str] = None, **kwargs
    ) -> int:
        """fave.addPost method

        :param owner_id:
        :param id:
        :param access_key:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addPost", params)
        model = OkResponse
        return model(**response).response

    async def add_product(
        self, owner_id: int, id: int, access_key: typing.Optional[str] = None, **kwargs
    ) -> int:
        """fave.addProduct method

        :param owner_id:
        :param id:
        :param access_key:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addProduct", params)
        model = OkResponse
        return model(**response).response

    async def add_tag(
        self,
        name: typing.Optional[str] = None,
        position: typing.Optional[Literal["back", "front"]] = None,
        **kwargs
    ) -> FaveTag:
        """fave.addTag method

        :param name:
        :param position:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addTag", params)
        model = AddTagResponse
        return model(**response).response

    async def add_video(
        self, owner_id: int, id: int, access_key: typing.Optional[str] = None, **kwargs
    ) -> int:
        """fave.addVideo method

        :param owner_id:
        :param id:
        :param access_key:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addVideo", params)
        model = OkResponse
        return model(**response).response

    async def edit_tag(self, id: int, name: str, **kwargs) -> int:
        """fave.editTag method

        :param id:
        :param name:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.editTag", params)
        model = OkResponse
        return model(**response).response

    @typing.overload
    async def get(
        self,
        extended: typing.Optional[Literal[False]] = ...,
        item_type: typing.Optional[
            Literal[
                "article",
                "clip",
                "link",
                "narrative",
                "page",
                "podcast",
                "post",
                "product",
                "video",
                "youla_product",
            ]
        ] = None,
        tag_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[str] = None,
        is_from_snackbar: typing.Optional[bool] = None,
        **kwargs
    ) -> GetResponseModel:
        ...

    @typing.overload
    async def get(
        self,
        extended: Literal[True] = ...,
        item_type: typing.Optional[
            Literal[
                "article",
                "clip",
                "link",
                "narrative",
                "page",
                "podcast",
                "post",
                "product",
                "video",
                "youla_product",
            ]
        ] = None,
        tag_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[str] = None,
        is_from_snackbar: typing.Optional[bool] = None,
        **kwargs
    ) -> GetExtendedResponseModel:
        ...

    async def get(
        self,
        extended=None,
        item_type=None,
        tag_id=None,
        offset=None,
        count=None,
        fields=None,
        is_from_snackbar=None,
        **kwargs
    ) -> typing.Union[GetResponseModel, GetExtendedResponseModel]:
        """fave.get method

        :param extended: '1' — to return additional 'wall', 'profiles', and 'groups' fields. By default: '0'.
        :param item_type:
        :param tag_id: Tag ID.
        :param offset: Offset needed to return a specific subset of users.
        :param count: Number of users to return.
        :param fields:
        :param is_from_snackbar:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.get", params)
        model = self.get_model(
            ((("extended",), GetExtendedResponse),),
            default=GetResponse,
            params=params,
        )
        return model(**response).response

    async def get_pages(
        self,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        type: typing.Optional[Literal["groups", "hints", "users"]] = None,
        fields: typing.Optional[typing.List[str]] = None,
        tag_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetPagesResponseModel:
        """fave.getPages method

        :param offset:
        :param count:
        :param type:
        :param fields:
        :param tag_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.getPages", params)
        model = GetPagesResponse
        return model(**response).response

    async def get_tags(self, **kwargs) -> GetTagsResponseModel:
        """fave.getTags method"""

        params = self.get_set_params(locals())
        response = await self.api.request("fave.getTags", params)
        model = GetTagsResponse
        return model(**response).response

    async def mark_seen(self, **kwargs) -> BaseBoolInt:
        """fave.markSeen method"""

        params = self.get_set_params(locals())
        response = await self.api.request("fave.markSeen", params)
        model = BoolResponse
        return model(**response).response

    async def remove_article(
        self, owner_id: int, article_id: int, **kwargs
    ) -> BaseBoolInt:
        """fave.removeArticle method

        :param owner_id:
        :param article_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removeArticle", params)
        model = BoolResponse
        return model(**response).response

    async def remove_link(
        self,
        link_id: typing.Optional[str] = None,
        link: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """Removes link from the user's faves.

        :param link_id: Link ID (can be obtained by [vk.com/dev/faves.getLinks|faves.getLinks] method).
        :param link: Link URL
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removeLink", params)
        model = OkResponse
        return model(**response).response

    async def remove_page(
        self,
        user_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """fave.removePage method

        :param user_id:
        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removePage", params)
        model = OkResponse
        return model(**response).response

    async def remove_post(self, owner_id: int, id: int, **kwargs) -> int:
        """fave.removePost method

        :param owner_id:
        :param id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removePost", params)
        model = OkResponse
        return model(**response).response

    async def remove_product(self, owner_id: int, id: int, **kwargs) -> int:
        """fave.removeProduct method

        :param owner_id:
        :param id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removeProduct", params)
        model = OkResponse
        return model(**response).response

    async def remove_tag(self, id: int, **kwargs) -> int:
        """fave.removeTag method

        :param id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removeTag", params)
        model = OkResponse
        return model(**response).response

    async def remove_video(self, owner_id: int, id: int, **kwargs) -> int:
        """fave.removeVideo method

        :param owner_id:
        :param id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removeVideo", params)
        model = OkResponse
        return model(**response).response

    async def reorder_tags(self, ids: typing.List[int], **kwargs) -> int:
        """fave.reorderTags method

        :param ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.reorderTags", params)
        model = OkResponse
        return model(**response).response

    async def set_page_tags(
        self,
        user_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        tag_ids: typing.Optional[typing.List[int]] = None,
        **kwargs
    ) -> int:
        """fave.setPageTags method

        :param user_id:
        :param group_id:
        :param tag_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.setPageTags", params)
        model = OkResponse
        return model(**response).response

    async def set_tags(
        self,
        item_type: typing.Optional[
            Literal[
                "article",
                "clip",
                "link",
                "narrative",
                "page",
                "podcast",
                "post",
                "product",
                "video",
                "youla_product",
            ]
        ] = None,
        item_owner_id: typing.Optional[int] = None,
        item_id: typing.Optional[int] = None,
        tag_ids: typing.Optional[typing.List[int]] = None,
        link_id: typing.Optional[str] = None,
        link_url: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """fave.setTags method

        :param item_type:
        :param item_owner_id:
        :param item_id:
        :param tag_ids:
        :param link_id:
        :param link_url:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.setTags", params)
        model = OkResponse
        return model(**response).response

    async def track_page_interaction(
        self,
        user_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """fave.trackPageInteraction method

        :param user_id:
        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.trackPageInteraction", params)
        model = OkResponse
        return model(**response).response


__all__ = ("FaveCategory",)



import inspect
import typing

from vkbottle_types.objects import (
    FriendsFriendExtendedStatus,
    FriendsFriendsList,
    FriendsFriendStatus,
    FriendsMutualFriend,
    FriendsRequests,
    FriendsRequestsXtrMessage,
    FriendsUserXtrPhone,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class AddListResponse(BaseResponse):
    response: "AddListResponseModel"


class AddResponse(BaseResponse):
    response: int


class AreFriendsExtendedResponse(BaseResponse):
    response: typing.List["FriendsFriendExtendedStatus"]


class AreFriendsResponse(BaseResponse):
    response: typing.List["FriendsFriendStatus"]


class DeleteResponse(BaseResponse):
    response: "DeleteResponseModel"


class GetAppUsersResponse(BaseResponse):
    response: typing.List[int]


class GetByPhonesResponse(BaseResponse):
    response: typing.List["FriendsUserXtrPhone"]


class GetListsResponse(BaseResponse):
    response: "GetListsResponseModel"


class GetMutualResponse(BaseResponse):
    response: typing.List[int]


class GetMutualTargetUidsResponse(BaseResponse):
    response: typing.List["FriendsMutualFriend"]


class GetOnlineOnlineMobileResponse(BaseResponse):
    response: "GetOnlineOnlineMobileResponseModel"


class GetOnlineResponse(BaseResponse):
    response: typing.List[int]


class GetRecentResponse(BaseResponse):
    response: typing.List[int]


class GetRequestsExtendedResponse(BaseResponse):
    response: "GetRequestsExtendedResponseModel"


class GetRequestsNeedMutualResponse(BaseResponse):
    response: "GetRequestsNeedMutualResponseModel"


class GetRequestsResponse(BaseResponse):
    response: "GetRequestsResponseModel"


class GetSuggestionsResponse(BaseResponse):
    response: "GetSuggestionsResponseModel"


class GetFieldsResponse(BaseResponse):
    response: "GetFieldsResponseModel"


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class SearchResponse(BaseResponse):
    response: "SearchResponseModel"


class AddListResponseModel(BaseResponse):
    list_id: typing.Optional[int] = None


class DeleteResponseModel(BaseResponse):
    success: typing.Optional[int] = None
    friend_deleted: typing.Optional[int] = None
    out_request_deleted: typing.Optional[int] = None
    in_request_deleted: typing.Optional[int] = None
    suggestion_deleted: typing.Optional[int] = None


class GetListsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["FriendsFriendsList"]] = None


class GetOnlineOnlineMobileResponseModel(BaseResponse):
    online: typing.Optional[typing.List[int]] = None
    online_mobile: typing.Optional[typing.List[int]] = None


class GetRequestsExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["FriendsRequestsXtrMessage"]] = None


class GetRequestsNeedMutualResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["FriendsRequests"]] = None


class GetRequestsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None
    count_unread: typing.Optional[int] = None


class GetSuggestionsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


class GetFieldsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class SearchResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddListResponse",
    "AddListResponseModel",
    "AddResponse",
    "AreFriendsExtendedResponse",
    "AreFriendsResponse",
    "DeleteResponse",
    "DeleteResponseModel",
    "FriendsFriendExtendedStatus",
    "FriendsFriendStatus",
    "FriendsFriendsList",
    "FriendsMutualFriend",
    "FriendsRequests",
    "FriendsRequestsXtrMessage",
    "FriendsUserXtrPhone",
    "GetAppUsersResponse",
    "GetByPhonesResponse",
    "GetFieldsResponse",
    "GetFieldsResponseModel",
    "GetListsResponse",
    "GetListsResponseModel",
    "GetMutualResponse",
    "GetMutualTargetUidsResponse",
    "GetOnlineOnlineMobileResponse",
    "GetOnlineOnlineMobileResponseModel",
    "GetOnlineResponse",
    "GetRecentResponse",
    "GetRequestsExtendedResponse",
    "GetRequestsExtendedResponseModel",
    "GetRequestsNeedMutualResponse",
    "GetRequestsNeedMutualResponseModel",
    "GetRequestsResponse",
    "GetRequestsResponseModel",
    "GetResponse",
    "GetResponseModel",
    "GetSuggestionsResponse",
    "GetSuggestionsResponseModel",
    "SearchResponse",
    "SearchResponseModel",
    "UsersUserFull",
)



import inspect
import typing

from vkbottle_types.objects import AppWidgetsPhoto, AppWidgetsPhotos
from vkbottle_types.responses.base_response import BaseResponse


class GetAppImageUploadServerResponse(BaseResponse):
    response: "GetAppImageUploadServerResponseModel"


class GetAppImagesResponse(BaseResponse):
    response: AppWidgetsPhotos


class GetGroupImageUploadServerResponse(BaseResponse):
    response: "GetGroupImageUploadServerResponseModel"


class GetGroupImagesResponse(BaseResponse):
    response: AppWidgetsPhotos


class GetImagesByIdResponse(BaseResponse):
    response: typing.List["AppWidgetsPhoto"]


class SaveAppImageResponse(BaseResponse):
    response: AppWidgetsPhoto


class SaveGroupImageResponse(BaseResponse):
    response: AppWidgetsPhoto


class GetAppImageUploadServerResponseModel(BaseResponse):
    upload_url: typing.Optional[str] = None


class GetGroupImageUploadServerResponseModel(BaseResponse):
    upload_url: typing.Optional[str] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AppWidgetsPhoto",
    "AppWidgetsPhotos",
    "GetAppImageUploadServerResponse",
    "GetAppImageUploadServerResponseModel",
    "GetAppImagesResponse",
    "GetGroupImageUploadServerResponse",
    "GetGroupImageUploadServerResponseModel",
    "GetGroupImagesResponse",
    "GetImagesByIdResponse",
    "SaveAppImageResponse",
    "SaveGroupImageResponse",
)



import inspect

from vkbottle_types.objects import BaseBoolInt, BaseUploadServer
from vkbottle_types.responses.base_response import BaseResponse


class BoolResponse(BaseResponse):
    response: BaseBoolInt


class OkResponse(BaseResponse):
    response: int


class BaseGetUploadServerResponse(BaseResponse):
    response: BaseUploadServer


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "BaseBoolInt",
    "BaseGetUploadServerResponse",
    "BaseUploadServer",
    "BoolResponse",
    "OkResponse",
)



import typing

if typing.TYPE_CHECKING:
    from vkbottle import ABCAPI

# from typing import NamedTuple
# RequestMethod = NamedTuple("RequestMethod", [("base_name", str), ("method_name", str), ("params", dict)])


T = typing.TypeVar("T")


class BaseCategory:
    def __init__(self, api: "ABCAPI"):
        self.api = api

    @classmethod
    def get_set_params(cls, params: dict) -> dict:
        exclude_params = params.copy()
        exclude_params.update(params["kwargs"])
        exclude_params.pop("kwargs")
        return {
            k if not k.startswith("_") else k[1:]: v
            for k, v in exclude_params.items()
            if k != "self" and v is not None
        }

    @classmethod
    def get_model(
        cls,
        dependent: typing.Tuple[
            typing.Tuple[typing.Tuple[typing.Union[str, typing.List[str]], ...], T], ...
        ],
        default: T,
        params: dict,
    ) -> T:
        """Choices model depending on params"""
        for items in sorted(dependent, key=lambda x: len(x[0])):
            keys, model = items
            for key in keys:
                if isinstance(key, str) and params.get(key) is None:
                    break
                elif isinstance(key, list) and params.get(key[0]) not in key[1:]:
                    break
            else:
                return model

        return default

    @classmethod
    def construct_api(cls, api: "ABCAPI") -> typing.Type["BaseCategory"]:
        cls.api = api
        return cls



import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import (
    BaseBoolInt,
    BaseGetUploadServerResponse,
    BaseUploadServer,
    OkResponse,
)
from vkbottle_types.responses.photos import (
    CopyResponse,
    CreateAlbumResponse,
    CreateCommentResponse,
    DeleteCommentResponse,
    GetAlbumsCountResponse,
    GetAlbumsResponse,
    GetAlbumsResponseModel,
    GetAllCommentsResponse,
    GetAllCommentsResponseModel,
    GetAllExtendedResponse,
    GetAllExtendedResponseModel,
    GetAllResponse,
    GetAllResponseModel,
    GetByIdResponse,
    GetCommentsExtendedResponse,
    GetCommentsExtendedResponseModel,
    GetCommentsResponse,
    GetCommentsResponseModel,
    GetMarketUploadServerResponse,
    GetMessagesUploadServerResponse,
    GetNewTagsResponse,
    GetNewTagsResponseModel,
    GetResponse,
    GetResponseModel,
    GetTagsResponse,
    GetUploadServerResponse,
    GetUserPhotosResponse,
    GetUserPhotosResponseModel,
    GetWallUploadServerResponse,
    PhotosPhoto,
    PhotosPhotoAlbumFull,
    PhotosPhotoTag,
    PhotosPhotoUpload,
    PutTagResponse,
    RestoreCommentResponse,
    SaveMarketAlbumPhotoResponse,
    SaveMarketPhotoResponse,
    SaveMessagesPhotoResponse,
    SaveOwnerCoverPhotoResponse,
    SaveOwnerCoverPhotoResponseModel,
    SaveOwnerPhotoResponse,
    SaveOwnerPhotoResponseModel,
    SaveResponse,
    SaveWallPhotoResponse,
    SearchResponse,
    SearchResponseModel,
)


class PhotosCategory(BaseCategory):
    async def confirm_tag(
        self,
        photo_id: str,
        tag_id: int,
        owner_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Confirms a tag on a photo.

        :param photo_id: Photo ID.
        :param tag_id: Tag ID.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.confirmTag", params)
        model = OkResponse
        return model(**response).response

    async def copy(
        self,
        owner_id: int,
        photo_id: int,
        access_key: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """Allows to copy a photo to the "Saved photos" album

        :param owner_id: photo's owner ID
        :param photo_id: photo ID
        :param access_key: for private photos
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.copy", params)
        model = CopyResponse
        return model(**response).response

    async def create_album(
        self,
        title: str,
        group_id: typing.Optional[int] = None,
        description: typing.Optional[str] = None,
        privacy_view: typing.Optional[typing.List[str]] = None,
        privacy_comment: typing.Optional[typing.List[str]] = None,
        upload_by_admins_only: typing.Optional[bool] = None,
        comments_disabled: typing.Optional[bool] = None,
        **kwargs
    ) -> PhotosPhotoAlbumFull:
        """Creates an empty photo album.

        :param title: Album title.
        :param group_id: ID of the community in which the album will be created.
        :param description: Album description.
        :param privacy_view:
        :param privacy_comment:
        :param upload_by_admins_only:
        :param comments_disabled:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.createAlbum", params)
        model = CreateAlbumResponse
        return model(**response).response

    async def create_comment(
        self,
        photo_id: int,
        owner_id: typing.Optional[int] = None,
        message: typing.Optional[str] = None,
        attachments: typing.Optional[typing.List[str]] = None,
        from_group: typing.Optional[bool] = None,
        reply_to_comment: typing.Optional[int] = None,
        sticker_id: typing.Optional[int] = None,
        access_key: typing.Optional[str] = None,
        guid: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """Adds a new comment on the photo.

        :param photo_id: Photo ID.
        :param owner_id: ID of the user or community that owns the photo.
        :param message: Comment text.
        :param attachments: (Required if 'message' is not set.) List of objects attached to the post, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, '<owner_id>' — Media attachment owner ID. '<media_id>' — Media attachment ID. Example: "photo100172_166443618,photo66748_265827614"
        :param from_group: '1' — to post a comment from the community
        :param reply_to_comment:
        :param sticker_id:
        :param access_key:
        :param guid:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.createComment", params)
        model = CreateCommentResponse
        return model(**response).response

    async def delete(
        self, photo_id: int, owner_id: typing.Optional[int] = None, **kwargs
    ) -> int:
        """Deletes a photo.

        :param photo_id: Photo ID.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.delete", params)
        model = OkResponse
        return model(**response).response

    async def delete_album(
        self, album_id: int, group_id: typing.Optional[int] = None, **kwargs
    ) -> int:
        """Deletes a photo album belonging to the current user.

        :param album_id: Album ID.
        :param group_id: ID of the community that owns the album.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.deleteAlbum", params)
        model = OkResponse
        return model(**response).response

    async def delete_comment(
        self, comment_id: int, owner_id: typing.Optional[int] = None, **kwargs
    ) -> BaseBoolInt:
        """Deletes a comment on the photo.

        :param comment_id: Comment ID.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.deleteComment", params)
        model = DeleteCommentResponse
        return model(**response).response

    async def edit(
        self,
        photo_id: int,
        owner_id: typing.Optional[int] = None,
        caption: typing.Optional[str] = None,
        latitude: typing.Optional[float] = None,
        longitude: typing.Optional[float] = None,
        place_str: typing.Optional[str] = None,
        foursquare_id: typing.Optional[str] = None,
        delete_place: typing.Optional[bool] = None,
        **kwargs
    ) -> int:
        """Edits the caption of a photo.

        :param photo_id: Photo ID.
        :param owner_id: ID of the user or community that owns the photo.
        :param caption: New caption for the photo. If this parameter is not set, it is considered to be equal to an empty string.
        :param latitude:
        :param longitude:
        :param place_str:
        :param foursquare_id:
        :param delete_place:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.edit", params)
        model = OkResponse
        return model(**response).response

    async def edit_album(
        self,
        album_id: int,
        title: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        owner_id: typing.Optional[int] = None,
        privacy_view: typing.Optional[typing.List[str]] = None,
        privacy_comment: typing.Optional[typing.List[str]] = None,
        upload_by_admins_only: typing.Optional[bool] = None,
        comments_disabled: typing.Optional[bool] = None,
        **kwargs
    ) -> int:
        """Edits information about a photo album.

        :param album_id: ID of the photo album to be edited.
        :param title: New album title.
        :param description: New album description.
        :param owner_id: ID of the user or community that owns the album.
        :param privacy_view:
        :param privacy_comment:
        :param upload_by_admins_only:
        :param comments_disabled:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.editAlbum", params)
        model = OkResponse
        return model(**response).response

    async def edit_comment(
        self,
        comment_id: int,
        owner_id: typing.Optional[int] = None,
        message: typing.Optional[str] = None,
        attachments: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> int:
        """Edits a comment on a photo.

        :param comment_id: Comment ID.
        :param owner_id: ID of the user or community that owns the photo.
        :param message: New text of the comment.
        :param attachments: (Required if 'message' is not set.) List of objects attached to the post, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, '<owner_id>' — Media attachment owner ID. '<media_id>' — Media attachment ID. Example: "photo100172_166443618,photo66748_265827614"
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.editComment", params)
        model = OkResponse
        return model(**response).response

    async def get(
        self,
        owner_id: typing.Optional[int] = None,
        album_id: typing.Optional[str] = None,
        photo_ids: typing.Optional[typing.List[str]] = None,
        rev: typing.Optional[bool] = None,
        extended: typing.Optional[bool] = None,
        feed_type: typing.Optional[str] = None,
        feed: typing.Optional[int] = None,
        photo_sizes: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetResponseModel:
        """Returns a list of a user's or community's photos.

        :param owner_id: ID of the user or community that owns the photos. Use a negative value to designate a community ID.
        :param album_id: Photo album ID. To return information about photos from service albums, use the following string values: 'profile, wall, saved'.
        :param photo_ids: Photo IDs.
        :param rev: Sort order: '1' — reverse chronological, '0' — chronological
        :param extended: '1' — to return additional 'likes', 'comments', and 'tags' fields, '0' — (default)
        :param feed_type: Type of feed obtained in 'feed' field of the method.
        :param feed: unixtime, that can be obtained with [vk.com/dev/newsfeed.get|newsfeed.get] method in date field to get all photos uploaded by the user on a specific day, or photos the user has been tagged on. Also, 'uid' parameter of the user the event happened with shall be specified.
        :param photo_sizes: '1' — to return photo sizes in a [vk.com/dev/photo_sizes|special format]
        :param offset:
        :param count:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.get", params)
        model = GetResponse
        return model(**response).response

    async def get_albums(
        self,
        owner_id: typing.Optional[int] = None,
        album_ids: typing.Optional[typing.List[int]] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        need_system: typing.Optional[bool] = None,
        need_covers: typing.Optional[bool] = None,
        photo_sizes: typing.Optional[bool] = None,
        **kwargs
    ) -> GetAlbumsResponseModel:
        """Returns a list of a user's or community's photo albums.

        :param owner_id: ID of the user or community that owns the albums.
        :param album_ids: Album IDs.
        :param offset: Offset needed to return a specific subset of albums.
        :param count: Number of albums to return.
        :param need_system: '1' — to return system albums with negative IDs
        :param need_covers: '1' — to return an additional 'thumb_src' field, '0' — (default)
        :param photo_sizes: '1' — to return photo sizes in a
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getAlbums", params)
        model = GetAlbumsResponse
        return model(**response).response

    async def get_albums_count(
        self,
        user_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Returns the number of photo albums belonging to a user or community.

        :param user_id: User ID.
        :param group_id: Community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getAlbumsCount", params)
        model = GetAlbumsCountResponse
        return model(**response).response

    @typing.overload
    async def get_all(
        self,
        owner_id: typing.Optional[int] = None,
        extended: typing.Optional[Literal[False]] = ...,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        photo_sizes: typing.Optional[bool] = None,
        no_service_albums: typing.Optional[bool] = None,
        need_hidden: typing.Optional[bool] = None,
        skip_hidden: typing.Optional[bool] = None,
        **kwargs
    ) -> GetAllResponseModel:
        ...

    @typing.overload
    async def get_all(
        self,
        owner_id: typing.Optional[int] = None,
        extended: Literal[True] = ...,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        photo_sizes: typing.Optional[bool] = None,
        no_service_albums: typing.Optional[bool] = None,
        need_hidden: typing.Optional[bool] = None,
        skip_hidden: typing.Optional[bool] = None,
        **kwargs
    ) -> GetAllExtendedResponseModel:
        ...

    async def get_all(
        self,
        owner_id=None,
        extended=None,
        offset=None,
        count=None,
        photo_sizes=None,
        no_service_albums=None,
        need_hidden=None,
        skip_hidden=None,
        **kwargs
    ) -> typing.Union[GetAllResponseModel, GetAllExtendedResponseModel]:
        """Returns a list of photos belonging to a user or community, in reverse chronological order.

        :param owner_id: ID of a user or community that owns the photos. Use a negative value to designate a community ID.
        :param extended: '1' — to return detailed information about photos
        :param offset: Offset needed to return a specific subset of photos. By default, '0'.
        :param count: Number of photos to return.
        :param photo_sizes: '1' - to return image sizes in [vk.com/dev/photo_sizes|special format].
        :param no_service_albums: '1' - to return photos only from standard albums, '0' - to return all photos including those in service albums, e.g., 'My wall photos' (default)
        :param need_hidden: '1' - to show information about photos being hidden from the block above the wall.
        :param skip_hidden: '1' - not to return photos being hidden from the block above the wall. Works only with owner_id>0, no_service_albums is ignored.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getAll", params)
        model = self.get_model(
            ((("extended",), GetAllExtendedResponse),),
            default=GetAllResponse,
            params=params,
        )
        return model(**response).response

    async def get_all_comments(
        self,
        owner_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = None,
        need_likes: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetAllCommentsResponseModel:
        """Returns a list of comments on a specific photo album or all albums of the user sorted in reverse chronological order.

        :param owner_id: ID of the user or community that owns the album(s).
        :param album_id: Album ID. If the parameter is not set, comments on all of the user's albums will be returned.
        :param need_likes: '1' — to return an additional 'likes' field, '0' — (default)
        :param offset: Offset needed to return a specific subset of comments. By default, '0'.
        :param count: Number of comments to return. By default, '20'. Maximum value, '100'.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getAllComments", params)
        model = GetAllCommentsResponse
        return model(**response).response

    async def get_by_id(
        self,
        photos: typing.List[str],
        extended: typing.Optional[bool] = None,
        photo_sizes: typing.Optional[bool] = None,
        **kwargs
    ) -> typing.List[PhotosPhoto]:
        """Returns information about photos by their IDs.

        :param photos: IDs separated with a comma, that are IDs of users who posted photos and IDs of photos themselves with an underscore character between such IDs. To get information about a photo in the group album, you shall specify group ID instead of user ID. Example: "1_129207899,6492_135055734, , -20629724_271945303"
        :param extended: '1' — to return additional fields, '0' — (default)
        :param photo_sizes: '1' — to return photo sizes in a
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getById", params)
        model = GetByIdResponse
        return model(**response).response

    async def get_chat_upload_server(
        self,
        chat_id: int,
        crop_x: typing.Optional[int] = None,
        crop_y: typing.Optional[int] = None,
        crop_width: typing.Optional[int] = None,
        **kwargs
    ) -> BaseUploadServer:
        """Returns an upload link for chat cover pictures.

        :param chat_id: ID of the chat for which you want to upload a cover photo.
        :param crop_x:
        :param crop_y:
        :param crop_width: Width (in pixels) of the photo after cropping.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getChatUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    @typing.overload
    async def get_comments(
        self,
        photo_id: int,
        owner_id: typing.Optional[int] = None,
        need_likes: typing.Optional[bool] = None,
        start_comment_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        sort: typing.Optional[Literal["asc", "desc"]] = None,
        access_key: typing.Optional[str] = None,
        extended: typing.Optional[Literal[False]] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> GetCommentsResponseModel:
        ...

    @typing.overload
    async def get_comments(
        self,
        photo_id: int,
        owner_id: typing.Optional[int] = None,
        need_likes: typing.Optional[bool] = None,
        start_comment_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        sort: typing.Optional[Literal["asc", "desc"]] = None,
        access_key: typing.Optional[str] = None,
        extended: Literal[True] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> GetCommentsExtendedResponseModel:
        ...

    async def get_comments(
        self,
        photo_id=None,
        owner_id=None,
        need_likes=None,
        start_comment_id=None,
        offset=None,
        count=None,
        sort=None,
        access_key=None,
        extended=None,
        fields=None,
        **kwargs
    ) -> typing.Union[GetCommentsResponseModel, GetCommentsExtendedResponseModel]:
        """Returns a list of comments on a photo.

        :param photo_id: Photo ID.
        :param owner_id: ID of the user or community that owns the photo.
        :param need_likes: '1' — to return an additional 'likes' field, '0' — (default)
        :param start_comment_id:
        :param offset: Offset needed to return a specific subset of comments. By default, '0'.
        :param count: Number of comments to return.
        :param sort: Sort order: 'asc' — old first, 'desc' — new first
        :param access_key:
        :param extended:
        :param fields:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getComments", params)
        model = self.get_model(
            ((("extended",), GetCommentsExtendedResponse),),
            default=GetCommentsResponse,
            params=params,
        )
        return model(**response).response

    async def get_market_album_upload_server(
        self, group_id: int, **kwargs
    ) -> BaseUploadServer:
        """Returns the server address for market album photo upload.

        :param group_id: Community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getMarketAlbumUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def get_market_upload_server(
        self,
        group_id: int,
        main_photo: typing.Optional[bool] = None,
        crop_x: typing.Optional[int] = None,
        crop_y: typing.Optional[int] = None,
        crop_width: typing.Optional[int] = None,
        **kwargs
    ) -> BaseUploadServer:
        """Returns the server address for market photo upload.

        :param group_id: Community ID.
        :param main_photo: '1' if you want to upload the main item photo.
        :param crop_x: X coordinate of the crop left upper corner.
        :param crop_y: Y coordinate of the crop left upper corner.
        :param crop_width: Width of the cropped photo in px.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getMarketUploadServer", params)
        model = GetMarketUploadServerResponse
        return model(**response).response

    async def get_messages_upload_server(
        self, peer_id: typing.Optional[int] = None, **kwargs
    ) -> PhotosPhotoUpload:
        """Returns the server address for photo upload in a private message for a user.

        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getMessagesUploadServer", params)
        model = GetMessagesUploadServerResponse
        return model(**response).response

    async def get_new_tags(
        self,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetNewTagsResponseModel:
        """Returns a list of photos with tags that have not been viewed.

        :param offset: Offset needed to return a specific subset of photos.
        :param count: Number of photos to return.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getNewTags", params)
        model = GetNewTagsResponse
        return model(**response).response

    async def get_owner_cover_photo_upload_server(
        self,
        group_id: int,
        crop_x: typing.Optional[int] = None,
        crop_y: typing.Optional[int] = None,
        crop_x2: typing.Optional[int] = None,
        crop_y2: typing.Optional[int] = None,
        **kwargs
    ) -> BaseUploadServer:
        """Returns the server address for owner cover upload.

        :param group_id: ID of community that owns the album (if the photo will be uploaded to a community album).
        :param crop_x: X coordinate of the left-upper corner
        :param crop_y: Y coordinate of the left-upper corner
        :param crop_x2: X coordinate of the right-bottom corner
        :param crop_y2: Y coordinate of the right-bottom corner
        """

        params = self.get_set_params(locals())
        response = await self.api.request(
            "photos.getOwnerCoverPhotoUploadServer", params
        )
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def get_owner_photo_upload_server(
        self, owner_id: typing.Optional[int] = None, **kwargs
    ) -> BaseUploadServer:
        """Returns an upload server address for a profile or community photo.

        :param owner_id: identifier of a community or current user. "Note that community id must be negative. 'owner_id=1' - user, 'owner_id=-1' - community, "
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getOwnerPhotoUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def get_tags(
        self,
        photo_id: int,
        owner_id: typing.Optional[int] = None,
        access_key: typing.Optional[str] = None,
        **kwargs
    ) -> typing.List[PhotosPhotoTag]:
        """Returns a list of tags on a photo.

        :param photo_id: Photo ID.
        :param owner_id: ID of the user or community that owns the photo.
        :param access_key:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getTags", params)
        model = GetTagsResponse
        return model(**response).response

    async def get_upload_server(
        self,
        album_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> PhotosPhotoUpload:
        """Returns the server address for photo upload.

        :param album_id:
        :param group_id: ID of community that owns the album (if the photo will be uploaded to a community album).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getUploadServer", params)
        model = GetUploadServerResponse
        return model(**response).response

    async def get_user_photos(
        self,
        user_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: typing.Optional[bool] = None,
        sort: typing.Optional[str] = None,
        **kwargs
    ) -> GetUserPhotosResponseModel:
        """Returns a list of photos in which a user is tagged.

        :param user_id: User ID.
        :param offset: Offset needed to return a specific subset of photos. By default, '0'.
        :param count: Number of photos to return. Maximum value is 1000.
        :param extended: '1' — to return an additional 'likes' field, '0' — (default)
        :param sort: Sort order: '1' — by date the tag was added in ascending order, '0' — by date the tag was added in descending order
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getUserPhotos", params)
        model = GetUserPhotosResponse
        return model(**response).response

    async def get_wall_upload_server(
        self, group_id: typing.Optional[int] = None, **kwargs
    ) -> PhotosPhotoUpload:
        """Returns the server address for photo upload onto a user's wall.

        :param group_id: ID of community to whose wall the photo will be uploaded.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getWallUploadServer", params)
        model = GetWallUploadServerResponse
        return model(**response).response

    async def make_cover(
        self,
        photo_id: int,
        owner_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Makes a photo into an album cover.

        :param photo_id: Photo ID.
        :param owner_id: ID of the user or community that owns the photo.
        :param album_id: Album ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.makeCover", params)
        model = OkResponse
        return model(**response).response

    async def move(
        self,
        target_album_id: int,
        photo_ids: int,
        owner_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Moves a photo from one album to another.

        :param target_album_id: ID of the album to which the photo will be moved.
        :param photo_ids:
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.move", params)
        model = OkResponse
        return model(**response).response

    async def put_tag(
        self,
        photo_id: int,
        user_id: int,
        owner_id: typing.Optional[int] = None,
        x: typing.Optional[float] = None,
        y: typing.Optional[float] = None,
        x2: typing.Optional[float] = None,
        y2: typing.Optional[float] = None,
        **kwargs
    ) -> int:
        """Adds a tag on the photo.

        :param photo_id: Photo ID.
        :param user_id: ID of the user to be tagged.
        :param owner_id: ID of the user or community that owns the photo.
        :param x: Upper left-corner coordinate of the tagged area (as a percentage of the photo's width).
        :param y: Upper left-corner coordinate of the tagged area (as a percentage of the photo's height).
        :param x2: Lower right-corner coordinate of the tagged area (as a percentage of the photo's width).
        :param y2: Lower right-corner coordinate of the tagged area (as a percentage of the photo's height).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.putTag", params)
        model = PutTagResponse
        return model(**response).response

    async def remove_tag(
        self,
        photo_id: int,
        tag_id: int,
        owner_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Removes a tag from a photo.

        :param photo_id: Photo ID.
        :param tag_id: Tag ID.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.removeTag", params)
        model = OkResponse
        return model(**response).response

    async def reorder_albums(
        self,
        album_id: int,
        owner_id: typing.Optional[int] = None,
        before: typing.Optional[int] = None,
        after: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Reorders the album in the list of user albums.

        :param album_id: Album ID.
        :param owner_id: ID of the user or community that owns the album.
        :param before: ID of the album before which the album in question shall be placed.
        :param after: ID of the album after which the album in question shall be placed.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.reorderAlbums", params)
        model = OkResponse
        return model(**response).response

    async def reorder_photos(
        self,
        photo_id: int,
        owner_id: typing.Optional[int] = None,
        before: typing.Optional[int] = None,
        after: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Reorders the photo in the list of photos of the user album.

        :param photo_id: Photo ID.
        :param owner_id: ID of the user or community that owns the photo.
        :param before: ID of the photo before which the photo in question shall be placed.
        :param after: ID of the photo after which the photo in question shall be placed.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.reorderPhotos", params)
        model = OkResponse
        return model(**response).response

    async def report(
        self,
        owner_id: int,
        photo_id: int,
        reason: typing.Optional[Literal[0, 1, 2, 3, 4, 5, 6]] = None,
        **kwargs
    ) -> int:
        """Reports (submits a complaint about) a photo.

        :param owner_id: ID of the user or community that owns the photo.
        :param photo_id: Photo ID.
        :param reason: Reason for the complaint: '0' - spam, '1' - child pornography, '2' - extremism, '3' - violence, '4' - drug propaganda, '5' - adult material, '6' - insult, abuse
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.report", params)
        model = OkResponse
        return model(**response).response

    async def report_comment(
        self,
        owner_id: int,
        comment_id: int,
        reason: typing.Optional[Literal[0, 1, 2, 3, 4, 5, 6]] = None,
        **kwargs
    ) -> int:
        """Reports (submits a complaint about) a comment on a photo.

        :param owner_id: ID of the user or community that owns the photo.
        :param comment_id: ID of the comment being reported.
        :param reason: Reason for the complaint: '0' - spam, '1' - child pornography, '2' - extremism, '3' - violence, '4' - drug propaganda, '5' - adult material, '6' - insult, abuse
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.reportComment", params)
        model = OkResponse
        return model(**response).response

    async def restore(
        self, photo_id: int, owner_id: typing.Optional[int] = None, **kwargs
    ) -> int:
        """Restores a deleted photo.

        :param photo_id: Photo ID.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.restore", params)
        model = OkResponse
        return model(**response).response

    async def restore_comment(
        self, comment_id: int, owner_id: typing.Optional[int] = None, **kwargs
    ) -> BaseBoolInt:
        """Restores a deleted comment on a photo.

        :param comment_id: ID of the deleted comment.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.restoreComment", params)
        model = RestoreCommentResponse
        return model(**response).response

    async def save(
        self,
        album_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        server: typing.Optional[int] = None,
        photos_list: typing.Optional[str] = None,
        hash: typing.Optional[str] = None,
        latitude: typing.Optional[float] = None,
        longitude: typing.Optional[float] = None,
        caption: typing.Optional[str] = None,
        **kwargs
    ) -> typing.List[PhotosPhoto]:
        """Saves photos after successful uploading.

        :param album_id: ID of the album to save photos to.
        :param group_id: ID of the community to save photos to.
        :param server: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param photos_list: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param hash: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param latitude: Geographical latitude, in degrees (from '-90' to '90').
        :param longitude: Geographical longitude, in degrees (from '-180' to '180').
        :param caption: Text describing the photo. 2048 digits max.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.save", params)
        model = SaveResponse
        return model(**response).response

    async def save_market_album_photo(
        self, group_id: int, photo: str, server: int, hash: str, **kwargs
    ) -> typing.List[PhotosPhoto]:
        """Saves market album photos after successful uploading.

        :param group_id: Community ID.
        :param photo: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param server: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param hash: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveMarketAlbumPhoto", params)
        model = SaveMarketAlbumPhotoResponse
        return model(**response).response

    async def save_market_photo(
        self,
        photo: str,
        server: int,
        hash: str,
        group_id: typing.Optional[int] = None,
        crop_data: typing.Optional[str] = None,
        crop_hash: typing.Optional[str] = None,
        **kwargs
    ) -> typing.List[PhotosPhoto]:
        """Saves market photos after successful uploading.

        :param photo: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param server: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param hash: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param group_id: Community ID.
        :param crop_data: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param crop_hash: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveMarketPhoto", params)
        model = SaveMarketPhotoResponse
        return model(**response).response

    async def save_messages_photo(
        self,
        photo: str,
        server: typing.Optional[int] = None,
        hash: typing.Optional[str] = None,
        **kwargs
    ) -> typing.List[PhotosPhoto]:
        """Saves a photo after being successfully uploaded. URL obtained with [vk.com/dev/photos.getMessagesUploadServer|photos.getMessagesUploadServer] method.

        :param photo: Parameter returned when the photo is [vk.com/dev/upload_files|uploaded to the server].
        :param server:
        :param hash:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveMessagesPhoto", params)
        model = SaveMessagesPhotoResponse
        return model(**response).response

    async def save_owner_cover_photo(
        self, hash: str, photo: str, **kwargs
    ) -> SaveOwnerCoverPhotoResponseModel:
        """Saves cover photo after successful uploading.

        :param hash: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param photo: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveOwnerCoverPhoto", params)
        model = SaveOwnerCoverPhotoResponse
        return model(**response).response

    async def save_owner_photo(
        self,
        server: typing.Optional[str] = None,
        hash: typing.Optional[str] = None,
        photo: typing.Optional[str] = None,
        **kwargs
    ) -> SaveOwnerPhotoResponseModel:
        """Saves a profile or community photo. Upload URL can be got with the [vk.com/dev/photos.getOwnerPhotoUploadServer|photos.getOwnerPhotoUploadServer] method.

        :param server: parameter returned after [vk.com/dev/upload_files|photo upload].
        :param hash: parameter returned after [vk.com/dev/upload_files|photo upload].
        :param photo: parameter returned after [vk.com/dev/upload_files|photo upload].
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveOwnerPhoto", params)
        model = SaveOwnerPhotoResponse
        return model(**response).response

    async def save_wall_photo(
        self,
        photo: str,
        user_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        server: typing.Optional[int] = None,
        hash: typing.Optional[str] = None,
        latitude: typing.Optional[float] = None,
        longitude: typing.Optional[float] = None,
        caption: typing.Optional[str] = None,
        **kwargs
    ) -> typing.List[PhotosPhoto]:
        """Saves a photo to a user's or community's wall after being uploaded.

        :param photo: Parameter returned when the the photo is [vk.com/dev/upload_files|uploaded to the server].
        :param user_id: ID of the user on whose wall the photo will be saved.
        :param group_id: ID of community on whose wall the photo will be saved.
        :param server:
        :param hash:
        :param latitude: Geographical latitude, in degrees (from '-90' to '90').
        :param longitude: Geographical longitude, in degrees (from '-180' to '180').
        :param caption: Text describing the photo. 2048 digits max.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveWallPhoto", params)
        model = SaveWallPhotoResponse
        return model(**response).response

    async def search(
        self,
        q: typing.Optional[str] = None,
        lat: typing.Optional[float] = None,
        long: typing.Optional[float] = None,
        start_time: typing.Optional[int] = None,
        end_time: typing.Optional[int] = None,
        sort: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        radius: typing.Optional[int] = None,
        **kwargs
    ) -> SearchResponseModel:
        """Returns a list of photos.

        :param q: Search query string.
        :param lat: Geographical latitude, in degrees (from '-90' to '90').
        :param long: Geographical longitude, in degrees (from '-180' to '180').
        :param start_time:
        :param end_time:
        :param sort: Sort order:
        :param offset: Offset needed to return a specific subset of photos.
        :param count: Number of photos to return.
        :param radius: Radius of search in meters (works very approximately). Available values: '10', '100', '800', '6000', '50000'.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.search", params)
        model = SearchResponse
        return model(**response).response


__all__ = ("PhotosCategory",)



import inspect
import typing

from vkbottle_types.objects import LeadFormsForm, LeadFormsLead
from vkbottle_types.responses.base_response import BaseResponse


class CreateResponse(BaseResponse):
    response: "CreateResponseModel"


class DeleteResponse(BaseResponse):
    response: "DeleteResponseModel"


class GetLeadsResponse(BaseResponse):
    response: "GetLeadsResponseModel"


class GetResponse(BaseResponse):
    response: LeadFormsForm


class ListResponse(BaseResponse):
    response: typing.List["LeadFormsForm"]


class UploadUrlResponse(BaseResponse):
    response: str


class CreateResponseModel(BaseResponse):
    form_id: typing.Optional[int] = None
    url: typing.Optional[str] = None


class DeleteResponseModel(BaseResponse):
    form_id: typing.Optional[int] = None


class GetLeadsResponseModel(BaseResponse):
    leads: typing.Optional[typing.List["LeadFormsLead"]] = None
    next_page_token: typing.Optional[str] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "CreateResponse",
    "CreateResponseModel",
    "DeleteResponse",
    "DeleteResponseModel",
    "GetLeadsResponse",
    "GetLeadsResponseModel",
    "GetResponse",
    "LeadFormsForm",
    "LeadFormsLead",
    "ListResponse",
    "UploadUrlResponse",
)
